""" openconfig_vlan_types 

This module defines configuration and state variables for VLANs,
in addition to VLAN parameters associated with interfaces

"""
from collections import OrderedDict

from ydk.types import Entity as _Entity_
from ydk.types import EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YError, YModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class VlanModeType(Enum):
    """
    VlanModeType (Enum Class)

    VLAN interface mode (trunk or access)

    .. data:: ACCESS = 0

        Access mode VLAN interface (No 802.1q header)

    .. data:: TRUNK = 1

        Trunk mode VLAN interface

    """

    ACCESS = Enum.YLeaf(0, "ACCESS")

    TRUNK = Enum.YLeaf(1, "TRUNK")


class TPIDTYPES(Identity):
    """
    Base identity for TPID values that can override the VLAN
    ethertype value
    
    """
    _prefix = 'oc-vlan-types'
    _revision = '2016-05-26'

    def __init__(self, ns="http://openconfig.net/yang/vlan-types", pref="openconfig-vlan-types", tag="openconfig-vlan-types:TPID_TYPES"):
        super().__init__(ns, pref, tag)


class TPID0x8100(TPIDTYPES):
    """
    Default TPID value for 802.1q single\-tagged VLANs.
    
    """
    _prefix = 'oc-vlan-types'
    _revision = '2016-05-26'

    def __init__(self, ns="http://openconfig.net/yang/vlan-types", pref="openconfig-vlan-types", tag="openconfig-vlan-types:TPID_0x8100"):
        super().__init__(ns, pref, tag)


class TPID0x8A88(TPIDTYPES):
    """
    TPID value for 802.1ad provider bridging, Q\-in\-Q,
    or stacked VLANs
    
    """
    _prefix = 'oc-vlan-types'
    _revision = '2016-05-26'

    def __init__(self, ns="http://openconfig.net/yang/vlan-types", pref="openconfig-vlan-types", tag="openconfig-vlan-types:TPID_0x8A88"):
        super().__init__(ns, pref, tag)


class TPID0x9100(TPIDTYPES):
    """
    Alternate TPID value
    
    """
    _prefix = 'oc-vlan-types'
    _revision = '2016-05-26'

    def __init__(self, ns="http://openconfig.net/yang/vlan-types", pref="openconfig-vlan-types", tag="openconfig-vlan-types:TPID_0x9100"):
        super().__init__(ns, pref, tag)


class TPID0X9200(TPIDTYPES):
    """
    Alternate TPID value
    
    """
    _prefix = 'oc-vlan-types'
    _revision = '2016-05-26'

    def __init__(self, ns="http://openconfig.net/yang/vlan-types", pref="openconfig-vlan-types", tag="openconfig-vlan-types:TPID_0X9200"):
        super().__init__(ns, pref, tag)






""" openconfig_system_logging 

This module defines configuration and operational state data
for common logging facilities on network systems.

"""
from collections import OrderedDict

from ydk.types import Entity as _Entity_
from ydk.types import EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YError, YModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class SyslogSeverity(Enum):
    """
    SyslogSeverity (Enum Class)

    Syslog message severities

    .. data:: EMERGENCY = 0

        Emergency: system is unusable (0)

    .. data:: ALERT = 1

        Alert: action must be taken immediately (1)

    .. data:: CRITICAL = 2

        Critical: critical conditions (2)

    .. data:: ERROR = 3

        Error: error conditions (3)

    .. data:: WARNING = 4

        Warning: warning conditions (4)

    .. data:: NOTICE = 5

        Notice: normal but significant  condition(5)

    .. data:: INFORMATIONAL = 6

        Informational: informational messages (6)

    .. data:: DEBUG = 7

        Debug: debug-level messages (7)

    """

    EMERGENCY = Enum.YLeaf(0, "EMERGENCY")

    ALERT = Enum.YLeaf(1, "ALERT")

    CRITICAL = Enum.YLeaf(2, "CRITICAL")

    ERROR = Enum.YLeaf(3, "ERROR")

    WARNING = Enum.YLeaf(4, "WARNING")

    NOTICE = Enum.YLeaf(5, "NOTICE")

    INFORMATIONAL = Enum.YLeaf(6, "INFORMATIONAL")

    DEBUG = Enum.YLeaf(7, "DEBUG")


class SYSLOGFACILITY(Identity):
    """
    Base identity for Syslog message facilities.
    
    """
    _prefix = 'oc-log'
    _revision = '2017-09-18'

    def __init__(self, ns="http://openconfig.net/yang/system/logging", pref="openconfig-system-logging", tag="openconfig-system-logging:SYSLOG_FACILITY"):
        super().__init__(ns, pref, tag)


class LOGDESTINATIONTYPE(Identity):
    """
    Base identity for destination for logging messages
    
    """
    _prefix = 'oc-log'
    _revision = '2017-09-18'

    def __init__(self, ns="http://openconfig.net/yang/system/logging", pref="openconfig-system-logging", tag="openconfig-system-logging:LOG_DESTINATION_TYPE"):
        super().__init__(ns, pref, tag)


class ALL(SYSLOGFACILITY):
    """
    All supported facilities
    
    """
    _prefix = 'oc-log'
    _revision = '2017-09-18'

    def __init__(self, ns="http://openconfig.net/yang/system/logging", pref="openconfig-system-logging", tag="openconfig-system-logging:ALL"):
        super().__init__(ns, pref, tag)


class KERNEL(SYSLOGFACILITY):
    """
    The facility for kernel messages
    
    """
    _prefix = 'oc-log'
    _revision = '2017-09-18'

    def __init__(self, ns="http://openconfig.net/yang/system/logging", pref="openconfig-system-logging", tag="openconfig-system-logging:KERNEL"):
        super().__init__(ns, pref, tag)


class USER(SYSLOGFACILITY):
    """
    The facility for user\-level messages.
    
    """
    _prefix = 'oc-log'
    _revision = '2017-09-18'

    def __init__(self, ns="http://openconfig.net/yang/system/logging", pref="openconfig-system-logging", tag="openconfig-system-logging:USER"):
        super().__init__(ns, pref, tag)


class MAIL(SYSLOGFACILITY):
    """
    The facility for the mail system.
    
    """
    _prefix = 'oc-log'
    _revision = '2017-09-18'

    def __init__(self, ns="http://openconfig.net/yang/system/logging", pref="openconfig-system-logging", tag="openconfig-system-logging:MAIL"):
        super().__init__(ns, pref, tag)


class SYSTEMDAEMON(SYSLOGFACILITY):
    """
    The facility for the system daemons.
    
    """
    _prefix = 'oc-log'
    _revision = '2017-09-18'

    def __init__(self, ns="http://openconfig.net/yang/system/logging", pref="openconfig-system-logging", tag="openconfig-system-logging:SYSTEM_DAEMON"):
        super().__init__(ns, pref, tag)


class AUTH(SYSLOGFACILITY):
    """
    The facility for security/authorization messages.
    
    """
    _prefix = 'oc-log'
    _revision = '2017-09-18'

    def __init__(self, ns="http://openconfig.net/yang/system/logging", pref="openconfig-system-logging", tag="openconfig-system-logging:AUTH"):
        super().__init__(ns, pref, tag)


class SYSLOG(SYSLOGFACILITY):
    """
    The facility for messages generated internally by syslogd
    facility.
    
    """
    _prefix = 'oc-log'
    _revision = '2017-09-18'

    def __init__(self, ns="http://openconfig.net/yang/system/logging", pref="openconfig-system-logging", tag="openconfig-system-logging:SYSLOG"):
        super().__init__(ns, pref, tag)


class AUTHPRIV(SYSLOGFACILITY):
    """
    The facility for privileged security/authorization messages.
    
    """
    _prefix = 'oc-log'
    _revision = '2017-09-18'

    def __init__(self, ns="http://openconfig.net/yang/system/logging", pref="openconfig-system-logging", tag="openconfig-system-logging:AUTHPRIV"):
        super().__init__(ns, pref, tag)


class NTP(SYSLOGFACILITY):
    """
    The facility for the NTP subsystem.
    
    """
    _prefix = 'oc-log'
    _revision = '2017-09-18'

    def __init__(self, ns="http://openconfig.net/yang/system/logging", pref="openconfig-system-logging", tag="openconfig-system-logging:NTP"):
        super().__init__(ns, pref, tag)


class AUDIT(SYSLOGFACILITY):
    """
    The facility for log audit messages.
    
    """
    _prefix = 'oc-log'
    _revision = '2017-09-18'

    def __init__(self, ns="http://openconfig.net/yang/system/logging", pref="openconfig-system-logging", tag="openconfig-system-logging:AUDIT"):
        super().__init__(ns, pref, tag)


class CONSOLE(SYSLOGFACILITY):
    """
    The facility for log alert messages.
    
    """
    _prefix = 'oc-log'
    _revision = '2017-09-18'

    def __init__(self, ns="http://openconfig.net/yang/system/logging", pref="openconfig-system-logging", tag="openconfig-system-logging:CONSOLE"):
        super().__init__(ns, pref, tag)


class LOCAL0(SYSLOGFACILITY):
    """
    The facility for local use 0 messages.
    
    """
    _prefix = 'oc-log'
    _revision = '2017-09-18'

    def __init__(self, ns="http://openconfig.net/yang/system/logging", pref="openconfig-system-logging", tag="openconfig-system-logging:LOCAL0"):
        super().__init__(ns, pref, tag)


class LOCAL1(SYSLOGFACILITY):
    """
    The facility for local use 1 messages.
    
    """
    _prefix = 'oc-log'
    _revision = '2017-09-18'

    def __init__(self, ns="http://openconfig.net/yang/system/logging", pref="openconfig-system-logging", tag="openconfig-system-logging:LOCAL1"):
        super().__init__(ns, pref, tag)


class LOCAL2(SYSLOGFACILITY):
    """
    The facility for local use 2 messages.
    
    """
    _prefix = 'oc-log'
    _revision = '2017-09-18'

    def __init__(self, ns="http://openconfig.net/yang/system/logging", pref="openconfig-system-logging", tag="openconfig-system-logging:LOCAL2"):
        super().__init__(ns, pref, tag)


class LOCAL3(SYSLOGFACILITY):
    """
    The facility for local use 3 messages.
    
    """
    _prefix = 'oc-log'
    _revision = '2017-09-18'

    def __init__(self, ns="http://openconfig.net/yang/system/logging", pref="openconfig-system-logging", tag="openconfig-system-logging:LOCAL3"):
        super().__init__(ns, pref, tag)


class LOCAL4(SYSLOGFACILITY):
    """
    The facility for local use 4 messages.
    
    """
    _prefix = 'oc-log'
    _revision = '2017-09-18'

    def __init__(self, ns="http://openconfig.net/yang/system/logging", pref="openconfig-system-logging", tag="openconfig-system-logging:LOCAL4"):
        super().__init__(ns, pref, tag)


class LOCAL5(SYSLOGFACILITY):
    """
    The facility for local use 5 messages.
    
    """
    _prefix = 'oc-log'
    _revision = '2017-09-18'

    def __init__(self, ns="http://openconfig.net/yang/system/logging", pref="openconfig-system-logging", tag="openconfig-system-logging:LOCAL5"):
        super().__init__(ns, pref, tag)


class LOCAL6(SYSLOGFACILITY):
    """
    The facility for local use 6 messages.
    
    """
    _prefix = 'oc-log'
    _revision = '2017-09-18'

    def __init__(self, ns="http://openconfig.net/yang/system/logging", pref="openconfig-system-logging", tag="openconfig-system-logging:LOCAL6"):
        super().__init__(ns, pref, tag)


class LOCAL7(SYSLOGFACILITY):
    """
    The facility for local use 7 messages.
    
    """
    _prefix = 'oc-log'
    _revision = '2017-09-18'

    def __init__(self, ns="http://openconfig.net/yang/system/logging", pref="openconfig-system-logging", tag="openconfig-system-logging:LOCAL7"):
        super().__init__(ns, pref, tag)


class DESTCONSOLE(LOGDESTINATIONTYPE):
    """
    Directs log messages to the console
    
    """
    _prefix = 'oc-log'
    _revision = '2017-09-18'

    def __init__(self, ns="http://openconfig.net/yang/system/logging", pref="openconfig-system-logging", tag="openconfig-system-logging:DEST_CONSOLE"):
        super().__init__(ns, pref, tag)


class DESTBUFFER(LOGDESTINATIONTYPE):
    """
    Directs log messages to and in\-memory circular buffer
    
    """
    _prefix = 'oc-log'
    _revision = '2017-09-18'

    def __init__(self, ns="http://openconfig.net/yang/system/logging", pref="openconfig-system-logging", tag="openconfig-system-logging:DEST_BUFFER"):
        super().__init__(ns, pref, tag)


class DESTFILE(LOGDESTINATIONTYPE):
    """
    Directs log messages to a local file
    
    """
    _prefix = 'oc-log'
    _revision = '2017-09-18'

    def __init__(self, ns="http://openconfig.net/yang/system/logging", pref="openconfig-system-logging", tag="openconfig-system-logging:DEST_FILE"):
        super().__init__(ns, pref, tag)


class DESTREMOTE(LOGDESTINATIONTYPE):
    """
    Directs log messages to a remote syslog server
    
    """
    _prefix = 'oc-log'
    _revision = '2017-09-18'

    def __init__(self, ns="http://openconfig.net/yang/system/logging", pref="openconfig-system-logging", tag="openconfig-system-logging:DEST_REMOTE"):
        super().__init__(ns, pref, tag)






BUNDLE_NAME = "openconfig"

CAPABILITIES = {
    "openconfig-aaa": "2018-04-12",
    "openconfig-aaa-radius": "2017-09-18",
    "openconfig-aaa-tacacs": "2017-09-18",
    "openconfig-aaa-types": "2018-04-12",
    "openconfig-acl": "2017-05-26",
    "openconfig-aft": "2017-05-10",
    "openconfig-aft-common": "2017-05-10",
    "openconfig-aft-ethernet": "2017-05-10",
    "openconfig-aft-ipv4": "2017-05-10",
    "openconfig-aft-ipv6": "2017-05-10",
    "openconfig-aft-mpls": "2017-05-10",
    "openconfig-aft-network-instance": "2017-01-13",
    "openconfig-aft-pf": "2017-05-10",
    "openconfig-aft-types": "2017-05-10",
    "openconfig-alarm-types": "2018-01-16",
    "openconfig-alarms": "2018-01-16",
    "openconfig-bfd": "2018-11-21",
    "openconfig-bgp": "2017-02-02",
    "openconfig-bgp-common": "2017-02-02",
    "openconfig-bgp-common-multiprotocol": "2017-02-02",
    "openconfig-bgp-common-structure": "2017-02-02",
    "openconfig-bgp-global": "2017-02-02",
    "openconfig-bgp-neighbor": "2017-02-02",
    "openconfig-bgp-peer-group": "2017-02-02",
    "openconfig-bgp-policy": "2017-07-30",
    "openconfig-bgp-types": "2017-02-02",
    "openconfig-channel-monitor": "2018-11-21",
    "openconfig-extensions": "2018-10-17",
    "openconfig-if-aggregate": "2016-05-26",
    "openconfig-if-ethernet": "2020-05-06",
    "openconfig-if-ethernet-ext": "2018-11-21",
    "openconfig-if-ip": "2019-01-08",
    "openconfig-if-ip-ext": "2018-11-21",
    "openconfig-if-tunnel": "2018-11-21",
    "openconfig-if-types": "2018-01-05",
    "openconfig-inet-types": "2017-08-24",
    "openconfig-interfaces": "2016-05-26",
    "openconfig-isis": "2018-11-21",
    "openconfig-isis-lsdb-types": "2018-11-21",
    "openconfig-isis-lsp": "2018-11-21",
    "openconfig-isis-policy": "2018-11-21",
    "openconfig-isis-routing": "2018-11-21",
    "openconfig-isis-types": "2018-11-21",
    "openconfig-lacp": "2017-05-05",
    "openconfig-lldp": "2016-05-16",
    "openconfig-lldp-types": "2016-05-16",
    "openconfig-local-routing": "2017-05-15",
    "openconfig-mpls": "2017-03-22",
    "openconfig-mpls-igp": "2017-03-22",
    "openconfig-mpls-ldp": "2017-03-22",
    "openconfig-mpls-rsvp": "2017-03-22",
    "openconfig-mpls-sr": "2017-03-22",
    "openconfig-mpls-static": "2017-03-22",
    "openconfig-mpls-te": "2017-03-22",
    "openconfig-mpls-types": "2017-06-21",
    "openconfig-network-instance": "2017-01-13",
    "openconfig-network-instance-l2": "2017-01-13",
    "openconfig-network-instance-l3": "2017-01-13",
    "openconfig-network-instance-types": "2016-12-15",
    "openconfig-optical-amplifier": "2018-11-21",
    "openconfig-packet-match": "2017-05-26",
    "openconfig-packet-match-types": "2017-05-26",
    "openconfig-platform": "2018-06-29",
    "openconfig-platform-cpu": "2018-01-30",
    "openconfig-platform-ext": "2018-01-18",
    "openconfig-platform-fan": "2018-01-18",
    "openconfig-platform-linecard": "2017-08-03",
    "openconfig-platform-port": "2018-01-20",
    "openconfig-platform-psu": "2018-01-16",
    "openconfig-platform-transceiver": "2018-11-25",
    "openconfig-platform-types": "2018-11-21",
    "openconfig-policy-types": "2017-07-14",
    "openconfig-procmon": "2017-09-18",
    "openconfig-rib-bgp": "2016-04-11",
    "openconfig-rib-bgp-types": "2016-04-11",
    "openconfig-routing-policy": "2018-06-05",
    "openconfig-rsvp-sr-ext": "2017-03-06",
    "openconfig-segment-routing": "2017-01-12",
    "openconfig-system": "2018-07-17",
    "openconfig-system-logging": "2017-09-18",
    "openconfig-system-management": "2018-08-28",
    "openconfig-system-terminal": "2017-09-18",
    "openconfig-telemetry": "2016-02-04",
    "openconfig-terminal-device": "2018-11-21",
    "openconfig-transport-line-common": "2018-07-17",
    "openconfig-transport-line-protection": "2018-11-21",
    "openconfig-transport-types": "2019-06-27",
    "openconfig-types": "2018-11-21",
    "openconfig-vlan": "2016-05-26",
    "openconfig-vlan-types": "2016-05-26",
    "openconfig-yang-types": "2018-04-24",
}

ENTITY_LOOKUP = {
    ("http://openconfig.net/yang/acl", "acl"): "openconfig_acl.Acl",
    ("openconfig-acl", "acl"): "openconfig_acl.Acl",
    ("http://openconfig.net/yang/bfd", "bfd"): "openconfig_bfd.Bfd",
    ("openconfig-bfd", "bfd"): "openconfig_bfd.Bfd",
    ("http://openconfig.net/yang/bgp", "bgp"): "openconfig_bgp.Bgp",
    ("openconfig-bgp", "bgp"): "openconfig_bgp.Bgp",
    ("http://openconfig.net/yang/channel-monitor", "channel-monitors"): "openconfig_channel_monitor.ChannelMonitors",
    ("openconfig-channel-monitor", "channel-monitors"): "openconfig_channel_monitor.ChannelMonitors",
    ("http://openconfig.net/yang/interfaces", "interfaces"): "openconfig_interfaces.Interfaces",
    ("openconfig-interfaces", "interfaces"): "openconfig_interfaces.Interfaces",
    ("http://openconfig.net/yang/lacp", "lacp"): "openconfig_lacp.Lacp",
    ("openconfig-lacp", "lacp"): "openconfig_lacp.Lacp",
    ("http://openconfig.net/yang/lldp", "lldp"): "openconfig_lldp.Lldp",
    ("openconfig-lldp", "lldp"): "openconfig_lldp.Lldp",
    ("http://openconfig.net/yang/local-routing", "local-routes"): "openconfig_local_routing.LocalRoutes",
    ("openconfig-local-routing", "local-routes"): "openconfig_local_routing.LocalRoutes",
    ("http://openconfig.net/yang/mpls", "mpls"): "openconfig_mpls.Mpls",
    ("openconfig-mpls", "mpls"): "openconfig_mpls.Mpls",
    ("http://openconfig.net/yang/network-instance", "network-instances"): "openconfig_network_instance.NetworkInstances",
    ("openconfig-network-instance", "network-instances"): "openconfig_network_instance.NetworkInstances",
    ("http://openconfig.net/yang/optical-amplfier", "optical-amplifier"): "openconfig_optical_amplifier.OpticalAmplifier",
    ("openconfig-optical-amplifier", "optical-amplifier"): "openconfig_optical_amplifier.OpticalAmplifier",
    ("http://openconfig.net/yang/platform", "components"): "openconfig_platform.Components",
    ("openconfig-platform", "components"): "openconfig_platform.Components",
    ("http://openconfig.net/yang/rib/bgp", "bgp-rib"): "openconfig_rib_bgp.BgpRib",
    ("openconfig-rib-bgp", "bgp-rib"): "openconfig_rib_bgp.BgpRib",
    ("http://openconfig.net/yang/routing-policy", "routing-policy"): "openconfig_routing_policy.RoutingPolicy",
    ("openconfig-routing-policy", "routing-policy"): "openconfig_routing_policy.RoutingPolicy",
    ("http://openconfig.net/yang/system", "system"): "openconfig_system.System",
    ("openconfig-system", "system"): "openconfig_system.System",
    ("http://openconfig.net/yang/telemetry", "telemetry-system"): "openconfig_telemetry.TelemetrySystem",
    ("openconfig-telemetry", "telemetry-system"): "openconfig_telemetry.TelemetrySystem",
    ("http://openconfig.net/yang/terminal-device", "terminal-device"): "openconfig_terminal_device.TerminalDevice",
    ("openconfig-terminal-device", "terminal-device"): "openconfig_terminal_device.TerminalDevice",
    ("http://openconfig.net/yang/optical-transport-line-protection", "aps"): "openconfig_transport_line_protection.Aps",
    ("openconfig-transport-line-protection", "aps"): "openconfig_transport_line_protection.Aps",
    ("http://openconfig.net/yang/vlan", "vlans"): "openconfig_vlan.Vlans",
    ("openconfig-vlan", "vlans"): "openconfig_vlan.Vlans",
}

NAMESPACE_LOOKUP = {
    "openconfig-aaa": "http://openconfig.net/yang/aaa",
    "openconfig-aaa-types": "http://openconfig.net/yang/aaa/types",
    "openconfig-acl": "http://openconfig.net/yang/acl",
    "openconfig-aft": "http://openconfig.net/yang/aft",
    "openconfig-aft-network-instance": "http://openconfig.net/yang/aft/ni",
    "openconfig-aft-types": "http://openconfig.net/yang/fib-types",
    "openconfig-alarm-types": "http://openconfig.net/yang/alarms/types",
    "openconfig-alarms": "http://openconfig.net/yang/alarms",
    "openconfig-bfd": "http://openconfig.net/yang/bfd",
    "openconfig-bgp": "http://openconfig.net/yang/bgp",
    "openconfig-bgp-policy": "http://openconfig.net/yang/bgp-policy",
    "openconfig-bgp-types": "http://openconfig.net/yang/bgp-types",
    "openconfig-channel-monitor": "http://openconfig.net/yang/channel-monitor",
    "openconfig-extensions": "http://openconfig.net/yang/openconfig-ext",
    "openconfig-if-aggregate": "http://openconfig.net/yang/interfaces/aggregate",
    "openconfig-if-ethernet": "http://openconfig.net/yang/interfaces/ethernet",
    "openconfig-if-ethernet-ext": "http://openconfig.net/yang/interfaces/ethernet-ext",
    "openconfig-if-ip": "http://openconfig.net/yang/interfaces/ip",
    "openconfig-if-ip-ext": "http://openconfig.net/yang/interfaces/ip-ext",
    "openconfig-if-tunnel": "http://openconfig.net/yang/interfaces/tunnel",
    "openconfig-if-types": "http://openconfig.net/yang/openconfig-if-types",
    "openconfig-inet-types": "http://openconfig.net/yang/types/inet",
    "openconfig-interfaces": "http://openconfig.net/yang/interfaces",
    "openconfig-isis": "http://openconfig.net/yang/openconfig-isis",
    "openconfig-isis-lsdb-types": "http://openconfig.net/yang/isis-lsdb-types",
    "openconfig-isis-policy": "http://openconfig.net/yang/openconfig-isis-policy",
    "openconfig-isis-types": "http://openconfig.net/yang/isis-types",
    "openconfig-lacp": "http://openconfig.net/yang/lacp",
    "openconfig-lldp": "http://openconfig.net/yang/lldp",
    "openconfig-lldp-types": "http://openconfig.net/yang/lldp/types",
    "openconfig-local-routing": "http://openconfig.net/yang/local-routing",
    "openconfig-mpls": "http://openconfig.net/yang/mpls",
    "openconfig-mpls-ldp": "http://openconfig.net/yang/ldp",
    "openconfig-mpls-rsvp": "http://openconfig.net/yang/rsvp",
    "openconfig-mpls-sr": "http://openconfig.net/yang/mpls-sr",
    "openconfig-mpls-types": "http://openconfig.net/yang/mpls-types",
    "openconfig-network-instance": "http://openconfig.net/yang/network-instance",
    "openconfig-network-instance-l3": "http://openconfig.net/yang/network-instance-l3",
    "openconfig-network-instance-types": "http://openconfig.net/yang/network-instance-types",
    "openconfig-optical-amplifier": "http://openconfig.net/yang/optical-amplfier",
    "openconfig-packet-match": "http://openconfig.net/yang/header-fields",
    "openconfig-packet-match-types": "http://openconfig.net/yang/packet-match-types",
    "openconfig-platform": "http://openconfig.net/yang/platform",
    "openconfig-platform-cpu": "http://openconfig.net/yang/platform/cpu",
    "openconfig-platform-ext": "http://openconfig.net/yang/platform/extension",
    "openconfig-platform-fan": "http://openconfig.net/yang/platform/fan",
    "openconfig-platform-linecard": "http://openconfig.net/yang/platform/linecard",
    "openconfig-platform-port": "http://openconfig.net/yang/platform/port",
    "openconfig-platform-psu": "http://openconfig.net/yang/platform/psu",
    "openconfig-platform-transceiver": "http://openconfig.net/yang/platform/transceiver",
    "openconfig-platform-types": "http://openconfig.net/yang/platform-types",
    "openconfig-policy-types": "http://openconfig.net/yang/policy-types",
    "openconfig-procmon": "http://openconfig.net/yang/system/procmon",
    "openconfig-rib-bgp": "http://openconfig.net/yang/rib/bgp",
    "openconfig-rib-bgp-types": "http://openconfig.net/yang/rib/bgp-types",
    "openconfig-routing-policy": "http://openconfig.net/yang/routing-policy",
    "openconfig-rsvp-sr-ext": "http://openconfig.net/yang/rsvp-sr-ext",
    "openconfig-segment-routing": "http://openconfig.net/yang/sr",
    "openconfig-system": "http://openconfig.net/yang/system",
    "openconfig-system-logging": "http://openconfig.net/yang/system/logging",
    "openconfig-system-management": "http://openconfig.net/yang/system/management",
    "openconfig-system-terminal": "http://openconfig.net/yang/system/terminal",
    "openconfig-telemetry": "http://openconfig.net/yang/telemetry",
    "openconfig-terminal-device": "http://openconfig.net/yang/terminal-device",
    "openconfig-transport-line-common": "http://openconfig.net/yang/transport-line-common",
    "openconfig-transport-line-protection": "http://openconfig.net/yang/optical-transport-line-protection",
    "openconfig-transport-types": "http://openconfig.net/yang/transport-types",
    "openconfig-types": "http://openconfig.net/yang/openconfig-types",
    "openconfig-vlan": "http://openconfig.net/yang/vlan",
    "openconfig-vlan-types": "http://openconfig.net/yang/vlan-types",
    "openconfig-yang-types": "http://openconfig.net/yang/types/yang",
}

IDENTITY_LOOKUP = {
    'openconfig-aaa:RADIUS':('ydk.models.openconfig.openconfig_aaa', 'RADIUS'),
    'openconfig-aaa:TACACS':('ydk.models.openconfig.openconfig_aaa', 'TACACS'),
    'openconfig-aaa-types:AAA_ACCOUNTING_EVENT_COMMAND':('ydk.models.openconfig.openconfig_aaa_types', 'AAAACCOUNTINGEVENTCOMMAND'),
    'openconfig-aaa-types:AAA_ACCOUNTING_EVENT_LOGIN':('ydk.models.openconfig.openconfig_aaa_types', 'AAAACCOUNTINGEVENTLOGIN'),
    'openconfig-aaa-types:AAA_ACCOUNTING_EVENT_TYPE':('ydk.models.openconfig.openconfig_aaa_types', 'AAAACCOUNTINGEVENTTYPE'),
    'openconfig-aaa-types:AAA_AUTHORIZATION_EVENT_COMMAND':('ydk.models.openconfig.openconfig_aaa_types', 'AAAAUTHORIZATIONEVENTCOMMAND'),
    'openconfig-aaa-types:AAA_AUTHORIZATION_EVENT_CONFIG':('ydk.models.openconfig.openconfig_aaa_types', 'AAAAUTHORIZATIONEVENTCONFIG'),
    'openconfig-aaa-types:AAA_AUTHORIZATION_EVENT_TYPE':('ydk.models.openconfig.openconfig_aaa_types', 'AAAAUTHORIZATIONEVENTTYPE'),
    'openconfig-aaa-types:AAA_METHOD_TYPE':('ydk.models.openconfig.openconfig_aaa_types', 'AAAMETHODTYPE'),
    'openconfig-aaa-types:AAA_SERVER_TYPE':('ydk.models.openconfig.openconfig_aaa_types', 'AAASERVERTYPE'),
    'openconfig-aaa-types:LOCAL':('ydk.models.openconfig.openconfig_aaa_types', 'LOCAL'),
    'openconfig-aaa-types:RADIUS_ALL':('ydk.models.openconfig.openconfig_aaa_types', 'RADIUSALL'),
    'openconfig-aaa-types:SYSTEM_DEFINED_ROLES':('ydk.models.openconfig.openconfig_aaa_types', 'SYSTEMDEFINEDROLES'),
    'openconfig-aaa-types:SYSTEM_ROLE_ADMIN':('ydk.models.openconfig.openconfig_aaa_types', 'SYSTEMROLEADMIN'),
    'openconfig-aaa-types:TACACS_ALL':('ydk.models.openconfig.openconfig_aaa_types', 'TACACSALL'),
    'openconfig-acl:ACCEPT':('ydk.models.openconfig.openconfig_acl', 'ACCEPT'),
    'openconfig-acl:ACL_COUNTER_CAPABILITY':('ydk.models.openconfig.openconfig_acl', 'ACLCOUNTERCAPABILITY'),
    'openconfig-acl:ACL_IPV4':('ydk.models.openconfig.openconfig_acl', 'ACLIPV4'),
    'openconfig-acl:ACL_IPV6':('ydk.models.openconfig.openconfig_acl', 'ACLIPV6'),
    'openconfig-acl:ACL_L2':('ydk.models.openconfig.openconfig_acl', 'ACLL2'),
    'openconfig-acl:ACL_MIXED':('ydk.models.openconfig.openconfig_acl', 'ACLMIXED'),
    'openconfig-acl:ACL_TYPE':('ydk.models.openconfig.openconfig_acl', 'ACLTYPE'),
    'openconfig-acl:AGGREGATE_ONLY':('ydk.models.openconfig.openconfig_acl', 'AGGREGATEONLY'),
    'openconfig-acl:DROP':('ydk.models.openconfig.openconfig_acl', 'DROP'),
    'openconfig-acl:FORWARDING_ACTION':('ydk.models.openconfig.openconfig_acl', 'FORWARDINGACTION'),
    'openconfig-acl:INTERFACE_AGGREGATE':('ydk.models.openconfig.openconfig_acl', 'INTERFACEAGGREGATE'),
    'openconfig-acl:INTERFACE_ONLY':('ydk.models.openconfig.openconfig_acl', 'INTERFACEONLY'),
    'openconfig-acl:LOG_ACTION':('ydk.models.openconfig.openconfig_acl', 'LOGACTION'),
    'openconfig-acl:LOG_NONE':('ydk.models.openconfig.openconfig_acl', 'LOGNONE'),
    'openconfig-acl:LOG_SYSLOG':('ydk.models.openconfig.openconfig_acl', 'LOGSYSLOG'),
    'openconfig-acl:REJECT':('ydk.models.openconfig.openconfig_acl', 'REJECT'),
    'openconfig-alarm-types:AIS':('ydk.models.openconfig.openconfig_alarm_types', 'AIS'),
    'openconfig-alarm-types:CRITICAL':('ydk.models.openconfig.openconfig_alarm_types', 'CRITICAL'),
    'openconfig-alarm-types:EQPT':('ydk.models.openconfig.openconfig_alarm_types', 'EQPT'),
    'openconfig-alarm-types:LOS':('ydk.models.openconfig.openconfig_alarm_types', 'LOS'),
    'openconfig-alarm-types:MAJOR':('ydk.models.openconfig.openconfig_alarm_types', 'MAJOR'),
    'openconfig-alarm-types:MINOR':('ydk.models.openconfig.openconfig_alarm_types', 'MINOR'),
    'openconfig-alarm-types:OPENCONFIG_ALARM_SEVERITY':('ydk.models.openconfig.openconfig_alarm_types', 'OPENCONFIGALARMSEVERITY'),
    'openconfig-alarm-types:OPENCONFIG_ALARM_TYPE_ID':('ydk.models.openconfig.openconfig_alarm_types', 'OPENCONFIGALARMTYPEID'),
    'openconfig-alarm-types:OTS':('ydk.models.openconfig.openconfig_alarm_types', 'OTS'),
    'openconfig-alarm-types:UNKNOWN':('ydk.models.openconfig.openconfig_alarm_types', 'UNKNOWN'),
    'openconfig-alarm-types:WARNING':('ydk.models.openconfig.openconfig_alarm_types', 'WARNING'),
    'openconfig-bgp-types:ADD_PATHS':('ydk.models.openconfig.openconfig_bgp_types', 'ADDPATHS'),
    'openconfig-bgp-types:AFI_SAFI_TYPE':('ydk.models.openconfig.openconfig_bgp_types', 'AFISAFITYPE'),
    'openconfig-bgp-types:ASN32':('ydk.models.openconfig.openconfig_bgp_types', 'ASN32'),
    'openconfig-bgp-types:BGP_CAPABILITY':('ydk.models.openconfig.openconfig_bgp_types', 'BGPCAPABILITY'),
    'openconfig-bgp-types:BGP_WELL_KNOWN_STD_COMMUNITY':('ydk.models.openconfig.openconfig_bgp_types', 'BGPWELLKNOWNSTDCOMMUNITY'),
    'openconfig-bgp-types:GRACEFUL_RESTART':('ydk.models.openconfig.openconfig_bgp_types', 'GRACEFULRESTART'),
    'openconfig-bgp-types:IPV4_LABELED_UNICAST':('ydk.models.openconfig.openconfig_bgp_types', 'IPV4LABELEDUNICAST'),
    'openconfig-bgp-types:IPV4_UNICAST':('ydk.models.openconfig.openconfig_bgp_types', 'IPV4UNICAST'),
    'openconfig-bgp-types:IPV6_LABELED_UNICAST':('ydk.models.openconfig.openconfig_bgp_types', 'IPV6LABELEDUNICAST'),
    'openconfig-bgp-types:IPV6_UNICAST':('ydk.models.openconfig.openconfig_bgp_types', 'IPV6UNICAST'),
    'openconfig-bgp-types:L2VPN_EVPN':('ydk.models.openconfig.openconfig_bgp_types', 'L2VPNEVPN'),
    'openconfig-bgp-types:L2VPN_VPLS':('ydk.models.openconfig.openconfig_bgp_types', 'L2VPNVPLS'),
    'openconfig-bgp-types:L3VPN_IPV4_MULTICAST':('ydk.models.openconfig.openconfig_bgp_types', 'L3VPNIPV4MULTICAST'),
    'openconfig-bgp-types:L3VPN_IPV4_UNICAST':('ydk.models.openconfig.openconfig_bgp_types', 'L3VPNIPV4UNICAST'),
    'openconfig-bgp-types:L3VPN_IPV6_MULTICAST':('ydk.models.openconfig.openconfig_bgp_types', 'L3VPNIPV6MULTICAST'),
    'openconfig-bgp-types:L3VPN_IPV6_UNICAST':('ydk.models.openconfig.openconfig_bgp_types', 'L3VPNIPV6UNICAST'),
    'openconfig-bgp-types:MPBGP':('ydk.models.openconfig.openconfig_bgp_types', 'MPBGP'),
    'openconfig-bgp-types:NO_ADVERTISE':('ydk.models.openconfig.openconfig_bgp_types', 'NOADVERTISE'),
    'openconfig-bgp-types:NO_EXPORT':('ydk.models.openconfig.openconfig_bgp_types', 'NOEXPORT'),
    'openconfig-bgp-types:NO_EXPORT_SUBCONFED':('ydk.models.openconfig.openconfig_bgp_types', 'NOEXPORTSUBCONFED'),
    'openconfig-bgp-types:NOPEER':('ydk.models.openconfig.openconfig_bgp_types', 'NOPEER'),
    'openconfig-bgp-types:PRIVATE_AS_REMOVE_ALL':('ydk.models.openconfig.openconfig_bgp_types', 'PRIVATEASREMOVEALL'),
    'openconfig-bgp-types:PRIVATE_AS_REPLACE_ALL':('ydk.models.openconfig.openconfig_bgp_types', 'PRIVATEASREPLACEALL'),
    'openconfig-bgp-types:REMOVE_PRIVATE_AS_OPTION':('ydk.models.openconfig.openconfig_bgp_types', 'REMOVEPRIVATEASOPTION'),
    'openconfig-bgp-types:ROUTE_REFRESH':('ydk.models.openconfig.openconfig_bgp_types', 'ROUTEREFRESH'),
    'openconfig-if-ethernet:ETHERNET_SPEED':('ydk.models.openconfig.openconfig_if_ethernet', 'ETHERNETSPEED'),
    'openconfig-if-ethernet:SPEED_100GB':('ydk.models.openconfig.openconfig_if_ethernet', 'SPEED100GB'),
    'openconfig-if-ethernet:SPEED_100MB':('ydk.models.openconfig.openconfig_if_ethernet', 'SPEED100MB'),
    'openconfig-if-ethernet:SPEED_10GB':('ydk.models.openconfig.openconfig_if_ethernet', 'SPEED10GB'),
    'openconfig-if-ethernet:SPEED_10MB':('ydk.models.openconfig.openconfig_if_ethernet', 'SPEED10MB'),
    'openconfig-if-ethernet:SPEED_1GB':('ydk.models.openconfig.openconfig_if_ethernet', 'SPEED1GB'),
    'openconfig-if-ethernet:SPEED_200GB':('ydk.models.openconfig.openconfig_if_ethernet', 'SPEED200GB'),
    'openconfig-if-ethernet:SPEED_2500MB':('ydk.models.openconfig.openconfig_if_ethernet', 'SPEED2500MB'),
    'openconfig-if-ethernet:SPEED_25GB':('ydk.models.openconfig.openconfig_if_ethernet', 'SPEED25GB'),
    'openconfig-if-ethernet:SPEED_400GB':('ydk.models.openconfig.openconfig_if_ethernet', 'SPEED400GB'),
    'openconfig-if-ethernet:SPEED_40GB':('ydk.models.openconfig.openconfig_if_ethernet', 'SPEED40GB'),
    'openconfig-if-ethernet:SPEED_50GB':('ydk.models.openconfig.openconfig_if_ethernet', 'SPEED50GB'),
    'openconfig-if-ethernet:SPEED_5GB':('ydk.models.openconfig.openconfig_if_ethernet', 'SPEED5GB'),
    'openconfig-if-ethernet:SPEED_600GB':('ydk.models.openconfig.openconfig_if_ethernet', 'SPEED600GB'),
    'openconfig-if-ethernet:SPEED_800GB':('ydk.models.openconfig.openconfig_if_ethernet', 'SPEED800GB'),
    'openconfig-if-ethernet:SPEED_UNKNOWN':('ydk.models.openconfig.openconfig_if_ethernet', 'SPEEDUNKNOWN'),
    'openconfig-if-types:IF_AGGREGATE':('ydk.models.openconfig.openconfig_if_types', 'IFAGGREGATE'),
    'openconfig-if-types:IF_ETHERNET':('ydk.models.openconfig.openconfig_if_types', 'IFETHERNET'),
    'openconfig-if-types:IF_LOOPBACK':('ydk.models.openconfig.openconfig_if_types', 'IFLOOPBACK'),
    'openconfig-if-types:IF_ROUTED_VLAN':('ydk.models.openconfig.openconfig_if_types', 'IFROUTEDVLAN'),
    'openconfig-if-types:IF_SONET':('ydk.models.openconfig.openconfig_if_types', 'IFSONET'),
    'openconfig-if-types:IF_TUNNEL_GRE4':('ydk.models.openconfig.openconfig_if_types', 'IFTUNNELGRE4'),
    'openconfig-if-types:IF_TUNNEL_GRE6':('ydk.models.openconfig.openconfig_if_types', 'IFTUNNELGRE6'),
    'openconfig-if-types:INTERFACE_TYPE':('ydk.models.openconfig.openconfig_if_types', 'INTERFACETYPE'),
    'openconfig-isis-lsdb-types:AREA_ADDRESSES':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'AREAADDRESSES'),
    'openconfig-isis-lsdb-types:AUTHENTICATION':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'AUTHENTICATION'),
    'openconfig-isis-lsdb-types:DYNAMIC_NAME':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'DYNAMICNAME'),
    'openconfig-isis-lsdb-types:EXTENDED_IPV4_REACHABILITY':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'EXTENDEDIPV4REACHABILITY'),
    'openconfig-isis-lsdb-types:EXTENDED_IS_REACHABILITY':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'EXTENDEDISREACHABILITY'),
    'openconfig-isis-lsdb-types:IIS_NEIGHBORS':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'IISNEIGHBORS'),
    'openconfig-isis-lsdb-types:INSTANCE_ID':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'INSTANCEID'),
    'openconfig-isis-lsdb-types:IP_REACHABILITY_IPV4_ROUTER_ID':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'IPREACHABILITYIPV4ROUTERID'),
    'openconfig-isis-lsdb-types:IP_REACHABILITY_IPV6_ROUTER_ID':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'IPREACHABILITYIPV6ROUTERID'),
    'openconfig-isis-lsdb-types:IP_REACHABILITY_PREFIX_FLAGS':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'IPREACHABILITYPREFIXFLAGS'),
    'openconfig-isis-lsdb-types:IP_REACHABILITY_PREFIX_SID':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'IPREACHABILITYPREFIXSID'),
    'openconfig-isis-lsdb-types:IP_REACHABILITY_SUBTLVS_TYPE':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'IPREACHABILITYSUBTLVSTYPE'),
    'openconfig-isis-lsdb-types:IP_REACHABILITY_TAG':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'IPREACHABILITYTAG'),
    'openconfig-isis-lsdb-types:IP_REACHABILITY_TAG64':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'IPREACHABILITYTAG64'),
    'openconfig-isis-lsdb-types:IPV4_EXTERNAL_REACHABILITY':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'IPV4EXTERNALREACHABILITY'),
    'openconfig-isis-lsdb-types:IPV4_INTERFACE_ADDRESSES':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'IPV4INTERFACEADDRESSES'),
    'openconfig-isis-lsdb-types:IPV4_INTERNAL_REACHABILITY':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'IPV4INTERNALREACHABILITY'),
    'openconfig-isis-lsdb-types:IPV4_SRLG':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'IPV4SRLG'),
    'openconfig-isis-lsdb-types:IPV4_TE_ROUTER_ID':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'IPV4TEROUTERID'),
    'openconfig-isis-lsdb-types:IPV6_INTERFACE_ADDRESSES':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'IPV6INTERFACEADDRESSES'),
    'openconfig-isis-lsdb-types:IPV6_REACHABILITY':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'IPV6REACHABILITY'),
    'openconfig-isis-lsdb-types:IPV6_SRLG':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'IPV6SRLG'),
    'openconfig-isis-lsdb-types:IPV6_TE_ROUTER_ID':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'IPV6TEROUTERID'),
    'openconfig-isis-lsdb-types:ISIS_ALIAS_ID':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISALIASID'),
    'openconfig-isis-lsdb-types:ISIS_SUBTLV_TYPE':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISSUBTLVTYPE'),
    'openconfig-isis-lsdb-types:ISIS_TLV_TYPE':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISTLVTYPE'),
    'openconfig-isis-lsdb-types:IS_NEIGHBOR_ATTRIBUTE':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISNEIGHBORATTRIBUTE'),
    'openconfig-isis-lsdb-types:IS_REACHABILITY_ADJ_LAN_SID':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISREACHABILITYADJLANSID'),
    'openconfig-isis-lsdb-types:IS_REACHABILITY_ADJ_SID':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISREACHABILITYADJSID'),
    'openconfig-isis-lsdb-types:IS_REACHABILITY_ADMIN_GROUP':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISREACHABILITYADMINGROUP'),
    'openconfig-isis-lsdb-types:IS_REACHABILITY_AVAILABLE_BANDWIDTH':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISREACHABILITYAVAILABLEBANDWIDTH'),
    'openconfig-isis-lsdb-types:IS_REACHABILITY_BANDWIDTH_CONSTRAINTS':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISREACHABILITYBANDWIDTHCONSTRAINTS'),
    'openconfig-isis-lsdb-types:IS_REACHABILITY_EXTENDED_ADMIN_GROUP':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISREACHABILITYEXTENDEDADMINGROUP'),
    'openconfig-isis-lsdb-types:IS_REACHABILITY_IPV4_INTERFACE_ADDRESS':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISREACHABILITYIPV4INTERFACEADDRESS'),
    'openconfig-isis-lsdb-types:IS_REACHABILITY_IPV4_NEIGHBOR_ADDRESS':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISREACHABILITYIPV4NEIGHBORADDRESS'),
    'openconfig-isis-lsdb-types:IS_REACHABILITY_IPV6_INTERFACE_ADDRESS':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISREACHABILITYIPV6INTERFACEADDRESS'),
    'openconfig-isis-lsdb-types:IS_REACHABILITY_IPV6_NEIGHBOR_ADDRESS':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISREACHABILITYIPV6NEIGHBORADDRESS'),
    'openconfig-isis-lsdb-types:IS_REACHABILITY_LINK_ATTRIBUTES':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISREACHABILITYLINKATTRIBUTES'),
    'openconfig-isis-lsdb-types:IS_REACHABILITY_LINK_DELAY':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISREACHABILITYLINKDELAY'),
    'openconfig-isis-lsdb-types:IS_REACHABILITY_LINK_DELAY_VARIATION':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISREACHABILITYLINKDELAYVARIATION'),
    'openconfig-isis-lsdb-types:IS_REACHABILITY_LINK_ID':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISREACHABILITYLINKID'),
    'openconfig-isis-lsdb-types:IS_REACHABILITY_LINK_LOSS':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISREACHABILITYLINKLOSS'),
    'openconfig-isis-lsdb-types:IS_REACHABILITY_LINK_PROTECTION_TYPE':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISREACHABILITYLINKPROTECTIONTYPE'),
    'openconfig-isis-lsdb-types:IS_REACHABILITY_MAX_LINK_BANDWIDTH':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISREACHABILITYMAXLINKBANDWIDTH'),
    'openconfig-isis-lsdb-types:IS_REACHABILITY_MAX_RESERVABLE_BANDWIDTH':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISREACHABILITYMAXRESERVABLEBANDWIDTH'),
    'openconfig-isis-lsdb-types:IS_REACHABILITY_MIN_MAX_LINK_DELAY':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISREACHABILITYMINMAXLINKDELAY'),
    'openconfig-isis-lsdb-types:IS_REACHABILITY_RESIDUAL_BANDWIDTH':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISREACHABILITYRESIDUALBANDWIDTH'),
    'openconfig-isis-lsdb-types:IS_REACHABILITY_SUBTLVS_TYPE':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISREACHABILITYSUBTLVSTYPE'),
    'openconfig-isis-lsdb-types:IS_REACHABILITY_TE_DEFAULT_METRIC':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISREACHABILITYTEDEFAULTMETRIC'),
    'openconfig-isis-lsdb-types:IS_REACHABILITY_UNCONSTRAINED_LSP':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISREACHABILITYUNCONSTRAINEDLSP'),
    'openconfig-isis-lsdb-types:IS_REACHABILITY_UNRESERVED_BANDWIDTH':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISREACHABILITYUNRESERVEDBANDWIDTH'),
    'openconfig-isis-lsdb-types:IS_REACHABILITY_UTILIZED_BANDWIDTH':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISREACHABILITYUTILIZEDBANDWIDTH'),
    'openconfig-isis-lsdb-types:LSP_BUFFER_SIZE':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'LSPBUFFERSIZE'),
    'openconfig-isis-lsdb-types:MT_IPV4_REACHABILITY':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'MTIPV4REACHABILITY'),
    'openconfig-isis-lsdb-types:MT_IPV6_REACHABILITY':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'MTIPV6REACHABILITY'),
    'openconfig-isis-lsdb-types:MT_ISN':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'MTISN'),
    'openconfig-isis-lsdb-types:MT_IS_NEIGHBOR_ATTRIBUTE':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'MTISNEIGHBORATTRIBUTE'),
    'openconfig-isis-lsdb-types:MULTI_TOPOLOGY':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'MULTITOPOLOGY'),
    'openconfig-isis-lsdb-types:NLPID':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'NLPID'),
    'openconfig-isis-lsdb-types:PURGE_OI':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'PURGEOI'),
    'openconfig-isis-lsdb-types:ROUTER_CAPABILITY':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ROUTERCAPABILITY'),
    'openconfig-isis-lsdb-types:ROUTER_CAPABILITY_SR_ALGORITHM':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ROUTERCAPABILITYSRALGORITHM'),
    'openconfig-isis-lsdb-types:ROUTER_CAPABILITY_SR_CAPABILITY':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ROUTERCAPABILITYSRCAPABILITY'),
    'openconfig-isis-lsdb-types:ROUTER_CAPABILITY_SUBTLVS_TYPE':('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ROUTERCAPABILITYSUBTLVSTYPE'),
    'openconfig-isis-types:AFI_SAFI_TYPE':('ydk.models.openconfig.openconfig_isis_types', 'AFISAFITYPE'),
    'openconfig-isis-types:AFI_TYPE':('ydk.models.openconfig.openconfig_isis_types', 'AFITYPE'),
    'openconfig-isis-types:IPV4':('ydk.models.openconfig.openconfig_isis_types', 'IPV4'),
    'openconfig-isis-types:IPV4_MULTICAST':('ydk.models.openconfig.openconfig_isis_types', 'IPV4MULTICAST'),
    'openconfig-isis-types:IPV4_UNICAST':('ydk.models.openconfig.openconfig_isis_types', 'IPV4UNICAST'),
    'openconfig-isis-types:IPV6':('ydk.models.openconfig.openconfig_isis_types', 'IPV6'),
    'openconfig-isis-types:IPV6_MULTICAST':('ydk.models.openconfig.openconfig_isis_types', 'IPV6MULTICAST'),
    'openconfig-isis-types:IPV6_UNICAST':('ydk.models.openconfig.openconfig_isis_types', 'IPV6UNICAST'),
    'openconfig-isis-types:MT_TYPE':('ydk.models.openconfig.openconfig_isis_types', 'MTTYPE'),
    'openconfig-isis-types:MULTICAST':('ydk.models.openconfig.openconfig_isis_types', 'MULTICAST'),
    'openconfig-isis-types:OVERLOAD_RESET_TRIGGER_TYPE':('ydk.models.openconfig.openconfig_isis_types', 'OVERLOADRESETTRIGGERTYPE'),
    'openconfig-isis-types:SAFI_TYPE':('ydk.models.openconfig.openconfig_isis_types', 'SAFITYPE'),
    'openconfig-isis-types:UNICAST':('ydk.models.openconfig.openconfig_isis_types', 'UNICAST'),
    'openconfig-isis-types:WAIT_FOR_BGP':('ydk.models.openconfig.openconfig_isis_types', 'WAITFORBGP'),
    'openconfig-isis-types:WAIT_FOR_SYSTEM':('ydk.models.openconfig.openconfig_isis_types', 'WAITFORSYSTEM'),
    'openconfig-lldp-types:CHASSIS_ID':('ydk.models.openconfig.openconfig_lldp_types', 'CHASSISID'),
    'openconfig-lldp-types:C_VLAN':('ydk.models.openconfig.openconfig_lldp_types', 'CVLAN'),
    'openconfig-lldp-types:DOCSIS_CABLE_DEVICE':('ydk.models.openconfig.openconfig_lldp_types', 'DOCSISCABLEDEVICE'),
    'openconfig-lldp-types:LLDP_SYSTEM_CAPABILITY':('ydk.models.openconfig.openconfig_lldp_types', 'LLDPSYSTEMCAPABILITY'),
    'openconfig-lldp-types:LLDP_TLV':('ydk.models.openconfig.openconfig_lldp_types', 'LLDPTLV'),
    'openconfig-lldp-types:MAC_BRIDGE':('ydk.models.openconfig.openconfig_lldp_types', 'MACBRIDGE'),
    'openconfig-lldp-types:MANAGEMENT_ADDRESS':('ydk.models.openconfig.openconfig_lldp_types', 'MANAGEMENTADDRESS'),
    'openconfig-lldp-types:OTHER':('ydk.models.openconfig.openconfig_lldp_types', 'OTHER'),
    'openconfig-lldp-types:PORT_DESCRIPTION':('ydk.models.openconfig.openconfig_lldp_types', 'PORTDESCRIPTION'),
    'openconfig-lldp-types:PORT_ID':('ydk.models.openconfig.openconfig_lldp_types', 'PORTID'),
    'openconfig-lldp-types:REPEATER':('ydk.models.openconfig.openconfig_lldp_types', 'REPEATER'),
    'openconfig-lldp-types:ROUTER':('ydk.models.openconfig.openconfig_lldp_types', 'ROUTER'),
    'openconfig-lldp-types:STATION_ONLY':('ydk.models.openconfig.openconfig_lldp_types', 'STATIONONLY'),
    'openconfig-lldp-types:S_VLAN':('ydk.models.openconfig.openconfig_lldp_types', 'SVLAN'),
    'openconfig-lldp-types:SYSTEM_CAPABILITIES':('ydk.models.openconfig.openconfig_lldp_types', 'SYSTEMCAPABILITIES'),
    'openconfig-lldp-types:SYSTEM_DESCRIPTION':('ydk.models.openconfig.openconfig_lldp_types', 'SYSTEMDESCRIPTION'),
    'openconfig-lldp-types:SYSTEM_NAME':('ydk.models.openconfig.openconfig_lldp_types', 'SYSTEMNAME'),
    'openconfig-lldp-types:TELEPHONE':('ydk.models.openconfig.openconfig_lldp_types', 'TELEPHONE'),
    'openconfig-lldp-types:TWO_PORT_MAC_RELAY':('ydk.models.openconfig.openconfig_lldp_types', 'TWOPORTMACRELAY'),
    'openconfig-lldp-types:WLAN_ACCESS_POINT':('ydk.models.openconfig.openconfig_lldp_types', 'WLANACCESSPOINT'),
    'openconfig-local-routing:DROP':('ydk.models.openconfig.openconfig_local_routing', 'DROP'),
    'openconfig-local-routing:LOCAL_DEFINED_NEXT_HOP':('ydk.models.openconfig.openconfig_local_routing', 'LOCALDEFINEDNEXTHOP'),
    'openconfig-local-routing:LOCAL_LINK':('ydk.models.openconfig.openconfig_local_routing', 'LOCALLINK'),
    'openconfig-mpls-types:ADMIN_DOWN':('ydk.models.openconfig.openconfig_mpls_types', 'ADMINDOWN'),
    'openconfig-mpls-types:ADMIN_UP':('ydk.models.openconfig.openconfig_mpls_types', 'ADMINUP'),
    'openconfig-mpls-types:DOWN':('ydk.models.openconfig.openconfig_mpls_types', 'DOWN'),
    'openconfig-mpls-types:EGRESS':('ydk.models.openconfig.openconfig_mpls_types', 'EGRESS'),
    'openconfig-mpls-types:EXPLICIT':('ydk.models.openconfig.openconfig_mpls_types', 'EXPLICIT'),
    'openconfig-mpls-types:EXPLICITLY_DEFINED':('ydk.models.openconfig.openconfig_mpls_types', 'EXPLICITLYDEFINED'),
    'openconfig-mpls-types:EXTERNALLY_QUERIED':('ydk.models.openconfig.openconfig_mpls_types', 'EXTERNALLYQUERIED'),
    'openconfig-mpls-types:IMPLICIT':('ydk.models.openconfig.openconfig_mpls_types', 'IMPLICIT'),
    'openconfig-mpls-types:INGRESS':('ydk.models.openconfig.openconfig_mpls_types', 'INGRESS'),
    'openconfig-mpls-types:LINK_NODE_PROTECTION_REQUESTED':('ydk.models.openconfig.openconfig_mpls_types', 'LINKNODEPROTECTIONREQUESTED'),
    'openconfig-mpls-types:LINK_PROTECTION_REQUIRED':('ydk.models.openconfig.openconfig_mpls_types', 'LINKPROTECTIONREQUIRED'),
    'openconfig-mpls-types:LOCALLY_COMPUTED':('ydk.models.openconfig.openconfig_mpls_types', 'LOCALLYCOMPUTED'),
    'openconfig-mpls-types:LSP_METRIC_ABSOLUTE':('ydk.models.openconfig.openconfig_mpls_types', 'LSPMETRICABSOLUTE'),
    'openconfig-mpls-types:LSP_METRIC_INHERITED':('ydk.models.openconfig.openconfig_mpls_types', 'LSPMETRICINHERITED'),
    'openconfig-mpls-types:LSP_METRIC_RELATIVE':('ydk.models.openconfig.openconfig_mpls_types', 'LSPMETRICRELATIVE'),
    'openconfig-mpls-types:LSP_METRIC_TYPE':('ydk.models.openconfig.openconfig_mpls_types', 'LSPMETRICTYPE'),
    'openconfig-mpls-types:LSP_OPER_STATUS':('ydk.models.openconfig.openconfig_mpls_types', 'LSPOPERSTATUS'),
    'openconfig-mpls-types:LSP_ROLE':('ydk.models.openconfig.openconfig_mpls_types', 'LSPROLE'),
    'openconfig-mpls-types:NULL_LABEL_TYPE':('ydk.models.openconfig.openconfig_mpls_types', 'NULLLABELTYPE'),
    'openconfig-mpls-types:P2MP':('ydk.models.openconfig.openconfig_mpls_types', 'P2MP'),
    'openconfig-mpls-types:P2P':('ydk.models.openconfig.openconfig_mpls_types', 'P2P'),
    'openconfig-mpls-types:PATH_COMPUTATION_METHOD':('ydk.models.openconfig.openconfig_mpls_types', 'PATHCOMPUTATIONMETHOD'),
    'openconfig-mpls-types:PATH_SETUP_LDP':('ydk.models.openconfig.openconfig_mpls_types', 'PATHSETUPLDP'),
    'openconfig-mpls-types:PATH_SETUP_PROTOCOL':('ydk.models.openconfig.openconfig_mpls_types', 'PATHSETUPPROTOCOL'),
    'openconfig-mpls-types:PATH_SETUP_RSVP':('ydk.models.openconfig.openconfig_mpls_types', 'PATHSETUPRSVP'),
    'openconfig-mpls-types:PATH_SETUP_SR':('ydk.models.openconfig.openconfig_mpls_types', 'PATHSETUPSR'),
    'openconfig-mpls-types:PROTECTION_TYPE':('ydk.models.openconfig.openconfig_mpls_types', 'PROTECTIONTYPE'),
    'openconfig-mpls-types:TRANSIT':('ydk.models.openconfig.openconfig_mpls_types', 'TRANSIT'),
    'openconfig-mpls-types:TUNNEL_ADMIN_STATUS':('ydk.models.openconfig.openconfig_mpls_types', 'TUNNELADMINSTATUS'),
    'openconfig-mpls-types:TUNNEL_TYPE':('ydk.models.openconfig.openconfig_mpls_types', 'TUNNELTYPE'),
    'openconfig-mpls-types:UNPROTECTED':('ydk.models.openconfig.openconfig_mpls_types', 'UNPROTECTED'),
    'openconfig-mpls-types:UP':('ydk.models.openconfig.openconfig_mpls_types', 'UP'),
    'openconfig-network-instance-types:BGP_EVPN':('ydk.models.openconfig.openconfig_network_instance_types', 'BGPEVPN'),
    'openconfig-network-instance-types:BGP_VPLS':('ydk.models.openconfig.openconfig_network_instance_types', 'BGPVPLS'),
    'openconfig-network-instance-types:DEFAULT_INSTANCE':('ydk.models.openconfig.openconfig_network_instance_types', 'DEFAULTINSTANCE'),
    'openconfig-network-instance-types:ENCAPSULATION':('ydk.models.openconfig.openconfig_network_instance_types', 'ENCAPSULATION'),
    'openconfig-network-instance-types:ENDPOINT_TYPE':('ydk.models.openconfig.openconfig_network_instance_types', 'ENDPOINTTYPE'),
    'openconfig-network-instance-types:INSTANCE_LABEL':('ydk.models.openconfig.openconfig_network_instance_types', 'INSTANCELABEL'),
    'openconfig-network-instance-types:L2L3':('ydk.models.openconfig.openconfig_network_instance_types', 'L2L3'),
    'openconfig-network-instance-types:L2P2P':('ydk.models.openconfig.openconfig_network_instance_types', 'L2P2P'),
    'openconfig-network-instance-types:L2VSI':('ydk.models.openconfig.openconfig_network_instance_types', 'L2VSI'),
    'openconfig-network-instance-types:L3VRF':('ydk.models.openconfig.openconfig_network_instance_types', 'L3VRF'),
    'openconfig-network-instance-types:LABEL_ALLOCATION_MODE':('ydk.models.openconfig.openconfig_network_instance_types', 'LABELALLOCATIONMODE'),
    'openconfig-network-instance-types:LDP':('ydk.models.openconfig.openconfig_network_instance_types', 'LDP'),
    'openconfig-network-instance-types:LOCAL':('ydk.models.openconfig.openconfig_network_instance_types', 'LOCAL'),
    'openconfig-network-instance-types:MPLS':('ydk.models.openconfig.openconfig_network_instance_types', 'MPLS'),
    'openconfig-network-instance-types:NETWORK_INSTANCE_TYPE':('ydk.models.openconfig.openconfig_network_instance_types', 'NETWORKINSTANCETYPE'),
    'openconfig-network-instance-types:PER_NEXTHOP':('ydk.models.openconfig.openconfig_network_instance_types', 'PERNEXTHOP'),
    'openconfig-network-instance-types:PER_PREFIX':('ydk.models.openconfig.openconfig_network_instance_types', 'PERPREFIX'),
    'openconfig-network-instance-types:REMOTE':('ydk.models.openconfig.openconfig_network_instance_types', 'REMOTE'),
    'openconfig-network-instance-types:SIGNALLING_PROTOCOL':('ydk.models.openconfig.openconfig_network_instance_types', 'SIGNALLINGPROTOCOL'),
    'openconfig-network-instance-types:VXLAN':('ydk.models.openconfig.openconfig_network_instance_types', 'VXLAN'),
    'openconfig-optical-amplifier:BACKWARD_RAMAN':('ydk.models.openconfig.openconfig_optical_amplifier', 'BACKWARDRAMAN'),
    'openconfig-optical-amplifier:CONSTANT_GAIN':('ydk.models.openconfig.openconfig_optical_amplifier', 'CONSTANTGAIN'),
    'openconfig-optical-amplifier:CONSTANT_POWER':('ydk.models.openconfig.openconfig_optical_amplifier', 'CONSTANTPOWER'),
    'openconfig-optical-amplifier:DSF':('ydk.models.openconfig.openconfig_optical_amplifier', 'DSF'),
    'openconfig-optical-amplifier:EDFA':('ydk.models.openconfig.openconfig_optical_amplifier', 'EDFA'),
    'openconfig-optical-amplifier:FIBER_TYPE_PROFILE':('ydk.models.openconfig.openconfig_optical_amplifier', 'FIBERTYPEPROFILE'),
    'openconfig-optical-amplifier:FIXED_GAIN_RANGE':('ydk.models.openconfig.openconfig_optical_amplifier', 'FIXEDGAINRANGE'),
    'openconfig-optical-amplifier:FORWARD_RAMAN':('ydk.models.openconfig.openconfig_optical_amplifier', 'FORWARDRAMAN'),
    'openconfig-optical-amplifier:GAIN_RANGE':('ydk.models.openconfig.openconfig_optical_amplifier', 'GAINRANGE'),
    'openconfig-optical-amplifier:HIGH_GAIN_RANGE':('ydk.models.openconfig.openconfig_optical_amplifier', 'HIGHGAINRANGE'),
    'openconfig-optical-amplifier:HYBRID':('ydk.models.openconfig.openconfig_optical_amplifier', 'HYBRID'),
    'openconfig-optical-amplifier:LEAF':('ydk.models.openconfig.openconfig_optical_amplifier', 'LEAF'),
    'openconfig-optical-amplifier:LOW_GAIN_RANGE':('ydk.models.openconfig.openconfig_optical_amplifier', 'LOWGAINRANGE'),
    'openconfig-optical-amplifier:MID_GAIN_RANGE':('ydk.models.openconfig.openconfig_optical_amplifier', 'MIDGAINRANGE'),
    'openconfig-optical-amplifier:OPTICAL_AMPLIFIER_MODE':('ydk.models.openconfig.openconfig_optical_amplifier', 'OPTICALAMPLIFIERMODE'),
    'openconfig-optical-amplifier:OPTICAL_AMPLIFIER_TYPE':('ydk.models.openconfig.openconfig_optical_amplifier', 'OPTICALAMPLIFIERTYPE'),
    'openconfig-optical-amplifier:SSMF':('ydk.models.openconfig.openconfig_optical_amplifier', 'SSMF'),
    'openconfig-optical-amplifier:TWC':('ydk.models.openconfig.openconfig_optical_amplifier', 'TWC'),
    'openconfig-optical-amplifier:TWRS':('ydk.models.openconfig.openconfig_optical_amplifier', 'TWRS'),
    'openconfig-packet-match-types:ETHERTYPE':('ydk.models.openconfig.openconfig_packet_match_types', 'ETHERTYPE'),
    'openconfig-packet-match-types:ETHERTYPE_ARP':('ydk.models.openconfig.openconfig_packet_match_types', 'ETHERTYPEARP'),
    'openconfig-packet-match-types:ETHERTYPE_IPV4':('ydk.models.openconfig.openconfig_packet_match_types', 'ETHERTYPEIPV4'),
    'openconfig-packet-match-types:ETHERTYPE_IPV6':('ydk.models.openconfig.openconfig_packet_match_types', 'ETHERTYPEIPV6'),
    'openconfig-packet-match-types:ETHERTYPE_LLDP':('ydk.models.openconfig.openconfig_packet_match_types', 'ETHERTYPELLDP'),
    'openconfig-packet-match-types:ETHERTYPE_MPLS':('ydk.models.openconfig.openconfig_packet_match_types', 'ETHERTYPEMPLS'),
    'openconfig-packet-match-types:ETHERTYPE_ROCE':('ydk.models.openconfig.openconfig_packet_match_types', 'ETHERTYPEROCE'),
    'openconfig-packet-match-types:ETHERTYPE_VLAN':('ydk.models.openconfig.openconfig_packet_match_types', 'ETHERTYPEVLAN'),
    'openconfig-packet-match-types:IP_AUTH':('ydk.models.openconfig.openconfig_packet_match_types', 'IPAUTH'),
    'openconfig-packet-match-types:IP_GRE':('ydk.models.openconfig.openconfig_packet_match_types', 'IPGRE'),
    'openconfig-packet-match-types:IP_ICMP':('ydk.models.openconfig.openconfig_packet_match_types', 'IPICMP'),
    'openconfig-packet-match-types:IP_IGMP':('ydk.models.openconfig.openconfig_packet_match_types', 'IPIGMP'),
    'openconfig-packet-match-types:IP_L2TP':('ydk.models.openconfig.openconfig_packet_match_types', 'IPL2TP'),
    'openconfig-packet-match-types:IP_PIM':('ydk.models.openconfig.openconfig_packet_match_types', 'IPPIM'),
    'openconfig-packet-match-types:IP_PROTOCOL':('ydk.models.openconfig.openconfig_packet_match_types', 'IPPROTOCOL'),
    'openconfig-packet-match-types:IP_RSVP':('ydk.models.openconfig.openconfig_packet_match_types', 'IPRSVP'),
    'openconfig-packet-match-types:IP_TCP':('ydk.models.openconfig.openconfig_packet_match_types', 'IPTCP'),
    'openconfig-packet-match-types:IP_UDP':('ydk.models.openconfig.openconfig_packet_match_types', 'IPUDP'),
    'openconfig-packet-match-types:TCP_ACK':('ydk.models.openconfig.openconfig_packet_match_types', 'TCPACK'),
    'openconfig-packet-match-types:TCP_CWR':('ydk.models.openconfig.openconfig_packet_match_types', 'TCPCWR'),
    'openconfig-packet-match-types:TCP_ECE':('ydk.models.openconfig.openconfig_packet_match_types', 'TCPECE'),
    'openconfig-packet-match-types:TCP_FIN':('ydk.models.openconfig.openconfig_packet_match_types', 'TCPFIN'),
    'openconfig-packet-match-types:TCP_FLAGS':('ydk.models.openconfig.openconfig_packet_match_types', 'TCPFLAGS'),
    'openconfig-packet-match-types:TCP_PSH':('ydk.models.openconfig.openconfig_packet_match_types', 'TCPPSH'),
    'openconfig-packet-match-types:TCP_RST':('ydk.models.openconfig.openconfig_packet_match_types', 'TCPRST'),
    'openconfig-packet-match-types:TCP_SYN':('ydk.models.openconfig.openconfig_packet_match_types', 'TCPSYN'),
    'openconfig-packet-match-types:TCP_URG':('ydk.models.openconfig.openconfig_packet_match_types', 'TCPURG'),
    'openconfig-platform-types:ACTIVE':('ydk.models.openconfig.openconfig_platform_types', 'ACTIVE'),
    'openconfig-platform-types:BACKPLANE':('ydk.models.openconfig.openconfig_platform_types', 'BACKPLANE'),
    'openconfig-platform-types:CHASSIS':('ydk.models.openconfig.openconfig_platform_types', 'CHASSIS'),
    'openconfig-platform-types:COMPONENT_OPER_STATUS':('ydk.models.openconfig.openconfig_platform_types', 'COMPONENTOPERSTATUS'),
    'openconfig-platform-types:CONTROLLER_CARD':('ydk.models.openconfig.openconfig_platform_types', 'CONTROLLERCARD'),
    'openconfig-platform-types:CPU':('ydk.models.openconfig.openconfig_platform_types', 'CPU'),
    'openconfig-platform-types:DISABLED':('ydk.models.openconfig.openconfig_platform_types', 'DISABLED'),
    'openconfig-platform-types:FABRIC':('ydk.models.openconfig.openconfig_platform_types', 'FABRIC'),
    'openconfig-platform-types:FAN':('ydk.models.openconfig.openconfig_platform_types', 'FAN'),
    'openconfig-platform-types:FEC_AUTO':('ydk.models.openconfig.openconfig_platform_types', 'FECAUTO'),
    'openconfig-platform-types:FEC_DISABLED':('ydk.models.openconfig.openconfig_platform_types', 'FECDISABLED'),
    'openconfig-platform-types:FEC_ENABLED':('ydk.models.openconfig.openconfig_platform_types', 'FECENABLED'),
    'openconfig-platform-types:FEC_MODE_TYPE':('ydk.models.openconfig.openconfig_platform_types', 'FECMODETYPE'),
    'openconfig-platform-types:FEC_STATUS_LOCKED':('ydk.models.openconfig.openconfig_platform_types', 'FECSTATUSLOCKED'),
    'openconfig-platform-types:FEC_STATUS_TYPE':('ydk.models.openconfig.openconfig_platform_types', 'FECSTATUSTYPE'),
    'openconfig-platform-types:FEC_STATUS_UNLOCKED':('ydk.models.openconfig.openconfig_platform_types', 'FECSTATUSUNLOCKED'),
    'openconfig-platform-types:FRU':('ydk.models.openconfig.openconfig_platform_types', 'FRU'),
    'openconfig-platform-types:INACTIVE':('ydk.models.openconfig.openconfig_platform_types', 'INACTIVE'),
    'openconfig-platform-types:INTEGRATED_CIRCUIT':('ydk.models.openconfig.openconfig_platform_types', 'INTEGRATEDCIRCUIT'),
    'openconfig-platform-types:LINECARD':('ydk.models.openconfig.openconfig_platform_types', 'LINECARD'),
    'openconfig-platform-types:OPENCONFIG_HARDWARE_COMPONENT':('ydk.models.openconfig.openconfig_platform_types', 'OPENCONFIGHARDWARECOMPONENT'),
    'openconfig-platform-types:OPENCONFIG_SOFTWARE_COMPONENT':('ydk.models.openconfig.openconfig_platform_types', 'OPENCONFIGSOFTWARECOMPONENT'),
    'openconfig-platform-types:OPERATING_SYSTEM':('ydk.models.openconfig.openconfig_platform_types', 'OPERATINGSYSTEM'),
    'openconfig-platform-types:PORT':('ydk.models.openconfig.openconfig_platform_types', 'PORT'),
    'openconfig-platform-types:POWER_SUPPLY':('ydk.models.openconfig.openconfig_platform_types', 'POWERSUPPLY'),
    'openconfig-platform-types:SENSOR':('ydk.models.openconfig.openconfig_platform_types', 'SENSOR'),
    'openconfig-platform-types:STORAGE':('ydk.models.openconfig.openconfig_platform_types', 'STORAGE'),
    'openconfig-platform-types:TRANSCEIVER':('ydk.models.openconfig.openconfig_platform_types', 'TRANSCEIVER'),
    'openconfig-policy-types:ATTRIBUTE_COMPARISON':('ydk.models.openconfig.openconfig_policy_types', 'ATTRIBUTECOMPARISON'),
    'openconfig-policy-types:ATTRIBUTE_EQ':('ydk.models.openconfig.openconfig_policy_types', 'ATTRIBUTEEQ'),
    'openconfig-policy-types:ATTRIBUTE_GE':('ydk.models.openconfig.openconfig_policy_types', 'ATTRIBUTEGE'),
    'openconfig-policy-types:ATTRIBUTE_LE':('ydk.models.openconfig.openconfig_policy_types', 'ATTRIBUTELE'),
    'openconfig-policy-types:BGP':('ydk.models.openconfig.openconfig_policy_types', 'BGP'),
    'openconfig-policy-types:DIRECTLY_CONNECTED':('ydk.models.openconfig.openconfig_policy_types', 'DIRECTLYCONNECTED'),
    'openconfig-policy-types:INSTALL_PROTOCOL_TYPE':('ydk.models.openconfig.openconfig_policy_types', 'INSTALLPROTOCOLTYPE'),
    'openconfig-policy-types:ISIS':('ydk.models.openconfig.openconfig_policy_types', 'ISIS'),
    'openconfig-policy-types:LOCAL_AGGREGATE':('ydk.models.openconfig.openconfig_policy_types', 'LOCALAGGREGATE'),
    'openconfig-policy-types:OSPF':('ydk.models.openconfig.openconfig_policy_types', 'OSPF'),
    'openconfig-policy-types:OSPF3':('ydk.models.openconfig.openconfig_policy_types', 'OSPF3'),
    'openconfig-policy-types:STATIC':('ydk.models.openconfig.openconfig_policy_types', 'STATIC'),
    'openconfig-rib-bgp-types:AS_PATH_LONGER':('ydk.models.openconfig.openconfig_rib_bgp_types', 'ASPATHLONGER'),
    'openconfig-rib-bgp-types:BGP_NOT_SELECTED_BESTPATH':('ydk.models.openconfig.openconfig_rib_bgp_types', 'BGPNOTSELECTEDBESTPATH'),
    'openconfig-rib-bgp-types:BGP_NOT_SELECTED_POLICY':('ydk.models.openconfig.openconfig_rib_bgp_types', 'BGPNOTSELECTEDPOLICY'),
    'openconfig-rib-bgp-types:HIGHER_PEER_ADDRESS':('ydk.models.openconfig.openconfig_rib_bgp_types', 'HIGHERPEERADDRESS'),
    'openconfig-rib-bgp-types:HIGHER_ROUTER_ID':('ydk.models.openconfig.openconfig_rib_bgp_types', 'HIGHERROUTERID'),
    'openconfig-rib-bgp-types:INVALID_AS_LOOP':('ydk.models.openconfig.openconfig_rib_bgp_types', 'INVALIDASLOOP'),
    'openconfig-rib-bgp-types:INVALID_CLUSTER_LOOP':('ydk.models.openconfig.openconfig_rib_bgp_types', 'INVALIDCLUSTERLOOP'),
    'openconfig-rib-bgp-types:INVALID_CONFED':('ydk.models.openconfig.openconfig_rib_bgp_types', 'INVALIDCONFED'),
    'openconfig-rib-bgp-types:INVALID_ORIGINATOR':('ydk.models.openconfig.openconfig_rib_bgp_types', 'INVALIDORIGINATOR'),
    'openconfig-rib-bgp-types:INVALID_ROUTE_REASON':('ydk.models.openconfig.openconfig_rib_bgp_types', 'INVALIDROUTEREASON'),
    'openconfig-rib-bgp-types:LOCAL_PREF_LOWER':('ydk.models.openconfig.openconfig_rib_bgp_types', 'LOCALPREFLOWER'),
    'openconfig-rib-bgp-types:MED_HIGHER':('ydk.models.openconfig.openconfig_rib_bgp_types', 'MEDHIGHER'),
    'openconfig-rib-bgp-types:NEXTHOP_COST_HIGHER':('ydk.models.openconfig.openconfig_rib_bgp_types', 'NEXTHOPCOSTHIGHER'),
    'openconfig-rib-bgp-types:ORIGIN_TYPE_HIGHER':('ydk.models.openconfig.openconfig_rib_bgp_types', 'ORIGINTYPEHIGHER'),
    'openconfig-rib-bgp-types:PREFER_EXTERNAL':('ydk.models.openconfig.openconfig_rib_bgp_types', 'PREFEREXTERNAL'),
    'openconfig-rib-bgp-types:REJECTED_IMPORT_POLICY':('ydk.models.openconfig.openconfig_rib_bgp_types', 'REJECTEDIMPORTPOLICY'),
    'openconfig-system:NTP_AUTH_MD5':('ydk.models.openconfig.openconfig_system', 'NTPAUTHMD5'),
    'openconfig-system:NTP_AUTH_TYPE':('ydk.models.openconfig.openconfig_system', 'NTPAUTHTYPE'),
    'openconfig-system-logging:ALL':('ydk.models.openconfig.openconfig_system_logging', 'ALL'),
    'openconfig-system-logging:AUDIT':('ydk.models.openconfig.openconfig_system_logging', 'AUDIT'),
    'openconfig-system-logging:AUTH':('ydk.models.openconfig.openconfig_system_logging', 'AUTH'),
    'openconfig-system-logging:AUTHPRIV':('ydk.models.openconfig.openconfig_system_logging', 'AUTHPRIV'),
    'openconfig-system-logging:CONSOLE':('ydk.models.openconfig.openconfig_system_logging', 'CONSOLE'),
    'openconfig-system-logging:DEST_BUFFER':('ydk.models.openconfig.openconfig_system_logging', 'DESTBUFFER'),
    'openconfig-system-logging:DEST_CONSOLE':('ydk.models.openconfig.openconfig_system_logging', 'DESTCONSOLE'),
    'openconfig-system-logging:DEST_FILE':('ydk.models.openconfig.openconfig_system_logging', 'DESTFILE'),
    'openconfig-system-logging:DEST_REMOTE':('ydk.models.openconfig.openconfig_system_logging', 'DESTREMOTE'),
    'openconfig-system-logging:KERNEL':('ydk.models.openconfig.openconfig_system_logging', 'KERNEL'),
    'openconfig-system-logging:LOCAL0':('ydk.models.openconfig.openconfig_system_logging', 'LOCAL0'),
    'openconfig-system-logging:LOCAL1':('ydk.models.openconfig.openconfig_system_logging', 'LOCAL1'),
    'openconfig-system-logging:LOCAL2':('ydk.models.openconfig.openconfig_system_logging', 'LOCAL2'),
    'openconfig-system-logging:LOCAL3':('ydk.models.openconfig.openconfig_system_logging', 'LOCAL3'),
    'openconfig-system-logging:LOCAL4':('ydk.models.openconfig.openconfig_system_logging', 'LOCAL4'),
    'openconfig-system-logging:LOCAL5':('ydk.models.openconfig.openconfig_system_logging', 'LOCAL5'),
    'openconfig-system-logging:LOCAL6':('ydk.models.openconfig.openconfig_system_logging', 'LOCAL6'),
    'openconfig-system-logging:LOCAL7':('ydk.models.openconfig.openconfig_system_logging', 'LOCAL7'),
    'openconfig-system-logging:LOG_DESTINATION_TYPE':('ydk.models.openconfig.openconfig_system_logging', 'LOGDESTINATIONTYPE'),
    'openconfig-system-logging:MAIL':('ydk.models.openconfig.openconfig_system_logging', 'MAIL'),
    'openconfig-system-logging:NTP':('ydk.models.openconfig.openconfig_system_logging', 'NTP'),
    'openconfig-system-logging:SYSLOG':('ydk.models.openconfig.openconfig_system_logging', 'SYSLOG'),
    'openconfig-system-logging:SYSLOG_FACILITY':('ydk.models.openconfig.openconfig_system_logging', 'SYSLOGFACILITY'),
    'openconfig-system-logging:SYSTEM_DAEMON':('ydk.models.openconfig.openconfig_system_logging', 'SYSTEMDAEMON'),
    'openconfig-system-logging:USER':('ydk.models.openconfig.openconfig_system_logging', 'USER'),
    'openconfig-transport-line-common:ADD':('ydk.models.openconfig.openconfig_transport_line_common', 'ADD'),
    'openconfig-transport-line-common:DROP':('ydk.models.openconfig.openconfig_transport_line_common', 'DROP'),
    'openconfig-transport-line-common:EGRESS':('ydk.models.openconfig.openconfig_transport_line_common', 'EGRESS'),
    'openconfig-transport-line-common:INGRESS':('ydk.models.openconfig.openconfig_transport_line_common', 'INGRESS'),
    'openconfig-transport-line-common:MONITOR':('ydk.models.openconfig.openconfig_transport_line_common', 'MONITOR'),
    'openconfig-transport-line-common:OPTICAL_LINE_PORT_TYPE':('ydk.models.openconfig.openconfig_transport_line_common', 'OPTICALLINEPORTTYPE'),
    'openconfig-transport-line-protection:APS_PATHS':('ydk.models.openconfig.openconfig_transport_line_protection', 'APSPATHS'),
    'openconfig-transport-line-protection:PRIMARY':('ydk.models.openconfig.openconfig_transport_line_protection', 'PRIMARY'),
    'openconfig-transport-line-protection:SECONDARY':('ydk.models.openconfig.openconfig_transport_line_protection', 'SECONDARY'),
    'openconfig-transport-types:ADD':('ydk.models.openconfig.openconfig_transport_types', 'ADD'),
    'openconfig-transport-types:AMP':('ydk.models.openconfig.openconfig_transport_types', 'AMP'),
    'openconfig-transport-types:BMP':('ydk.models.openconfig.openconfig_transport_types', 'BMP'),
    'openconfig-transport-types:CBR':('ydk.models.openconfig.openconfig_transport_types', 'CBR'),
    'openconfig-transport-types:CFP':('ydk.models.openconfig.openconfig_transport_types', 'CFP'),
    'openconfig-transport-types:CFP2':('ydk.models.openconfig.openconfig_transport_types', 'CFP2'),
    'openconfig-transport-types:CFP2_ACO':('ydk.models.openconfig.openconfig_transport_types', 'CFP2ACO'),
    'openconfig-transport-types:CFP4':('ydk.models.openconfig.openconfig_transport_types', 'CFP4'),
    'openconfig-transport-types:CPAK':('ydk.models.openconfig.openconfig_transport_types', 'CPAK'),
    'openconfig-transport-types:DROP':('ydk.models.openconfig.openconfig_transport_types', 'DROP'),
    'openconfig-transport-types:EGRESS':('ydk.models.openconfig.openconfig_transport_types', 'EGRESS'),
    'openconfig-transport-types:ETH_100G_ACC':('ydk.models.openconfig.openconfig_transport_types', 'ETH100GACC'),
    'openconfig-transport-types:ETH_100G_AOC':('ydk.models.openconfig.openconfig_transport_types', 'ETH100GAOC'),
    'openconfig-transport-types:ETH_100GBASE_CLR4':('ydk.models.openconfig.openconfig_transport_types', 'ETH100GBASECLR4'),
    'openconfig-transport-types:ETH_100GBASE_CR4':('ydk.models.openconfig.openconfig_transport_types', 'ETH100GBASECR4'),
    'openconfig-transport-types:ETH_100GBASE_CWDM4':('ydk.models.openconfig.openconfig_transport_types', 'ETH100GBASECWDM4'),
    'openconfig-transport-types:ETH_100GBASE_ER4':('ydk.models.openconfig.openconfig_transport_types', 'ETH100GBASEER4'),
    'openconfig-transport-types:ETH_100GBASE_LR4':('ydk.models.openconfig.openconfig_transport_types', 'ETH100GBASELR4'),
    'openconfig-transport-types:ETH_100GBASE_PSM4':('ydk.models.openconfig.openconfig_transport_types', 'ETH100GBASEPSM4'),
    'openconfig-transport-types:ETH_100GBASE_SR10':('ydk.models.openconfig.openconfig_transport_types', 'ETH100GBASESR10'),
    'openconfig-transport-types:ETH_100GBASE_SR4':('ydk.models.openconfig.openconfig_transport_types', 'ETH100GBASESR4'),
    'openconfig-transport-types:ETH_10GBASE_ER':('ydk.models.openconfig.openconfig_transport_types', 'ETH10GBASEER'),
    'openconfig-transport-types:ETH_10GBASE_LR':('ydk.models.openconfig.openconfig_transport_types', 'ETH10GBASELR'),
    'openconfig-transport-types:ETH_10GBASE_LRM':('ydk.models.openconfig.openconfig_transport_types', 'ETH10GBASELRM'),
    'openconfig-transport-types:ETH_10GBASE_SR':('ydk.models.openconfig.openconfig_transport_types', 'ETH10GBASESR'),
    'openconfig-transport-types:ETH_10GBASE_ZR':('ydk.models.openconfig.openconfig_transport_types', 'ETH10GBASEZR'),
    'openconfig-transport-types:ETH_40GBASE_CR4':('ydk.models.openconfig.openconfig_transport_types', 'ETH40GBASECR4'),
    'openconfig-transport-types:ETH_40GBASE_ER4':('ydk.models.openconfig.openconfig_transport_types', 'ETH40GBASEER4'),
    'openconfig-transport-types:ETH_40GBASE_LR4':('ydk.models.openconfig.openconfig_transport_types', 'ETH40GBASELR4'),
    'openconfig-transport-types:ETH_40GBASE_PSM4':('ydk.models.openconfig.openconfig_transport_types', 'ETH40GBASEPSM4'),
    'openconfig-transport-types:ETH_40GBASE_SR4':('ydk.models.openconfig.openconfig_transport_types', 'ETH40GBASESR4'),
    'openconfig-transport-types:ETH_4X10GBASE_LR':('ydk.models.openconfig.openconfig_transport_types', 'ETH4X10GBASELR'),
    'openconfig-transport-types:ETH_4X10GBASE_SR':('ydk.models.openconfig.openconfig_transport_types', 'ETH4X10GBASESR'),
    'openconfig-transport-types:ETHERNET_PMD_TYPE':('ydk.models.openconfig.openconfig_transport_types', 'ETHERNETPMDTYPE'),
    'openconfig-transport-types:ETH_UNDEFINED':('ydk.models.openconfig.openconfig_transport_types', 'ETHUNDEFINED'),
    'openconfig-transport-types:FIBER_CONNECTOR_TYPE':('ydk.models.openconfig.openconfig_transport_types', 'FIBERCONNECTORTYPE'),
    'openconfig-transport-types:FIBER_JUMPER_MULTI_FIBER_STRAND':('ydk.models.openconfig.openconfig_transport_types', 'FIBERJUMPERMULTIFIBERSTRAND'),
    'openconfig-transport-types:FIBER_JUMPER_SIMPLEX':('ydk.models.openconfig.openconfig_transport_types', 'FIBERJUMPERSIMPLEX'),
    'openconfig-transport-types:FIBER_JUMPER_TYPE':('ydk.models.openconfig.openconfig_transport_types', 'FIBERJUMPERTYPE'),
    'openconfig-transport-types:FRAME_MAPPING_PROTOCOL':('ydk.models.openconfig.openconfig_transport_types', 'FRAMEMAPPINGPROTOCOL'),
    'openconfig-transport-types:GFP_F':('ydk.models.openconfig.openconfig_transport_types', 'GFPF'),
    'openconfig-transport-types:GFP_T':('ydk.models.openconfig.openconfig_transport_types', 'GFPT'),
    'openconfig-transport-types:GMP':('ydk.models.openconfig.openconfig_transport_types', 'GMP'),
    'openconfig-transport-types:INGRESS':('ydk.models.openconfig.openconfig_transport_types', 'INGRESS'),
    'openconfig-transport-types:LC_CONNECTOR':('ydk.models.openconfig.openconfig_transport_types', 'LCCONNECTOR'),
    'openconfig-transport-types:LOGICAL_ELEMENT_PROTOCOL_TYPE':('ydk.models.openconfig.openconfig_transport_types', 'LOGICALELEMENTPROTOCOLTYPE'),
    'openconfig-transport-types:MONITOR':('ydk.models.openconfig.openconfig_transport_types', 'MONITOR'),
    'openconfig-transport-types:MPO_CONNECTOR':('ydk.models.openconfig.openconfig_transport_types', 'MPOCONNECTOR'),
    'openconfig-transport-types:NON_PLUGGABLE':('ydk.models.openconfig.openconfig_transport_types', 'NONPLUGGABLE'),
    'openconfig-transport-types:OPTICAL_CHANNEL':('ydk.models.openconfig.openconfig_transport_types', 'OPTICALCHANNEL'),
    'openconfig-transport-types:OPTICAL_PORT_TYPE':('ydk.models.openconfig.openconfig_transport_types', 'OPTICALPORTTYPE'),
    'openconfig-transport-types:OTHER':('ydk.models.openconfig.openconfig_transport_types', 'OTHER'),
    'openconfig-transport-types:OTN_APPLICATION_CODE':('ydk.models.openconfig.openconfig_transport_types', 'OTNAPPLICATIONCODE'),
    'openconfig-transport-types:OTN_UNDEFINED':('ydk.models.openconfig.openconfig_transport_types', 'OTNUNDEFINED'),
    'openconfig-transport-types:P1L1_2D1':('ydk.models.openconfig.openconfig_transport_types', 'P1L12D1'),
    'openconfig-transport-types:P1L1_2D2':('ydk.models.openconfig.openconfig_transport_types', 'P1L12D2'),
    'openconfig-transport-types:P1S1_2D2':('ydk.models.openconfig.openconfig_transport_types', 'P1S12D2'),
    'openconfig-transport-types:PROT_100GE':('ydk.models.openconfig.openconfig_transport_types', 'PROT100GE'),
    'openconfig-transport-types:PROT_100G_MLG':('ydk.models.openconfig.openconfig_transport_types', 'PROT100GMLG'),
    'openconfig-transport-types:PROT_10GE_LAN':('ydk.models.openconfig.openconfig_transport_types', 'PROT10GELAN'),
    'openconfig-transport-types:PROT_10GE_WAN':('ydk.models.openconfig.openconfig_transport_types', 'PROT10GEWAN'),
    'openconfig-transport-types:PROT_1GE':('ydk.models.openconfig.openconfig_transport_types', 'PROT1GE'),
    'openconfig-transport-types:PROT_40GE':('ydk.models.openconfig.openconfig_transport_types', 'PROT40GE'),
    'openconfig-transport-types:PROT_ETHERNET':('ydk.models.openconfig.openconfig_transport_types', 'PROTETHERNET'),
    'openconfig-transport-types:PROT_OC192':('ydk.models.openconfig.openconfig_transport_types', 'PROTOC192'),
    'openconfig-transport-types:PROT_OC48':('ydk.models.openconfig.openconfig_transport_types', 'PROTOC48'),
    'openconfig-transport-types:PROT_OC768':('ydk.models.openconfig.openconfig_transport_types', 'PROTOC768'),
    'openconfig-transport-types:PROT_ODU2':('ydk.models.openconfig.openconfig_transport_types', 'PROTODU2'),
    'openconfig-transport-types:PROT_ODU2E':('ydk.models.openconfig.openconfig_transport_types', 'PROTODU2E'),
    'openconfig-transport-types:PROT_ODU3':('ydk.models.openconfig.openconfig_transport_types', 'PROTODU3'),
    'openconfig-transport-types:PROT_ODU4':('ydk.models.openconfig.openconfig_transport_types', 'PROTODU4'),
    'openconfig-transport-types:PROT_ODUCN':('ydk.models.openconfig.openconfig_transport_types', 'PROTODUCN'),
    'openconfig-transport-types:PROT_OTN':('ydk.models.openconfig.openconfig_transport_types', 'PROTOTN'),
    'openconfig-transport-types:PROT_OTU1E':('ydk.models.openconfig.openconfig_transport_types', 'PROTOTU1E'),
    'openconfig-transport-types:PROT_OTU2':('ydk.models.openconfig.openconfig_transport_types', 'PROTOTU2'),
    'openconfig-transport-types:PROT_OTU2E':('ydk.models.openconfig.openconfig_transport_types', 'PROTOTU2E'),
    'openconfig-transport-types:PROT_OTU3':('ydk.models.openconfig.openconfig_transport_types', 'PROTOTU3'),
    'openconfig-transport-types:PROT_OTU4':('ydk.models.openconfig.openconfig_transport_types', 'PROTOTU4'),
    'openconfig-transport-types:PROT_OTUCN':('ydk.models.openconfig.openconfig_transport_types', 'PROTOTUCN'),
    'openconfig-transport-types:PROT_STM16':('ydk.models.openconfig.openconfig_transport_types', 'PROTSTM16'),
    'openconfig-transport-types:PROT_STM256':('ydk.models.openconfig.openconfig_transport_types', 'PROTSTM256'),
    'openconfig-transport-types:PROT_STM64':('ydk.models.openconfig.openconfig_transport_types', 'PROTSTM64'),
    'openconfig-transport-types:QSFP':('ydk.models.openconfig.openconfig_transport_types', 'QSFP'),
    'openconfig-transport-types:QSFP28':('ydk.models.openconfig.openconfig_transport_types', 'QSFP28'),
    'openconfig-transport-types:QSFP_PLUS':('ydk.models.openconfig.openconfig_transport_types', 'QSFPPLUS'),
    'openconfig-transport-types:SC_CONNECTOR':('ydk.models.openconfig.openconfig_transport_types', 'SCCONNECTOR'),
    'openconfig-transport-types:SFP':('ydk.models.openconfig.openconfig_transport_types', 'SFP'),
    'openconfig-transport-types:SFP_PLUS':('ydk.models.openconfig.openconfig_transport_types', 'SFPPLUS'),
    'openconfig-transport-types:SONET_APPLICATION_CODE':('ydk.models.openconfig.openconfig_transport_types', 'SONETAPPLICATIONCODE'),
    'openconfig-transport-types:SONET_UNDEFINED':('ydk.models.openconfig.openconfig_transport_types', 'SONETUNDEFINED'),
    'openconfig-transport-types:TERMINAL_CLIENT':('ydk.models.openconfig.openconfig_transport_types', 'TERMINALCLIENT'),
    'openconfig-transport-types:TERMINAL_LINE':('ydk.models.openconfig.openconfig_transport_types', 'TERMINALLINE'),
    'openconfig-transport-types:TRANSCEIVER_FORM_FACTOR_TYPE':('ydk.models.openconfig.openconfig_transport_types', 'TRANSCEIVERFORMFACTORTYPE'),
    'openconfig-transport-types:TRIB_RATE_1000G':('ydk.models.openconfig.openconfig_transport_types', 'TRIBRATE1000G'),
    'openconfig-transport-types:TRIB_RATE_100G':('ydk.models.openconfig.openconfig_transport_types', 'TRIBRATE100G'),
    'openconfig-transport-types:TRIB_RATE_10G':('ydk.models.openconfig.openconfig_transport_types', 'TRIBRATE10G'),
    'openconfig-transport-types:TRIB_RATE_1100G':('ydk.models.openconfig.openconfig_transport_types', 'TRIBRATE1100G'),
    'openconfig-transport-types:TRIB_RATE_150G':('ydk.models.openconfig.openconfig_transport_types', 'TRIBRATE150G'),
    'openconfig-transport-types:TRIB_RATE_1G':('ydk.models.openconfig.openconfig_transport_types', 'TRIBRATE1G'),
    'openconfig-transport-types:TRIB_RATE_200G':('ydk.models.openconfig.openconfig_transport_types', 'TRIBRATE200G'),
    'openconfig-transport-types:TRIB_RATE_250G':('ydk.models.openconfig.openconfig_transport_types', 'TRIBRATE250G'),
    'openconfig-transport-types:TRIB_RATE_2.5G':('ydk.models.openconfig.openconfig_transport_types', 'TRIBRATE2DOT5G'),
    'openconfig-transport-types:TRIB_RATE_300G':('ydk.models.openconfig.openconfig_transport_types', 'TRIBRATE300G'),
    'openconfig-transport-types:TRIB_RATE_400G':('ydk.models.openconfig.openconfig_transport_types', 'TRIBRATE400G'),
    'openconfig-transport-types:TRIB_RATE_40G':('ydk.models.openconfig.openconfig_transport_types', 'TRIBRATE40G'),
    'openconfig-transport-types:TRIB_RATE_500G':('ydk.models.openconfig.openconfig_transport_types', 'TRIBRATE500G'),
    'openconfig-transport-types:TRIB_RATE_600G':('ydk.models.openconfig.openconfig_transport_types', 'TRIBRATE600G'),
    'openconfig-transport-types:TRIB_RATE_700G':('ydk.models.openconfig.openconfig_transport_types', 'TRIBRATE700G'),
    'openconfig-transport-types:TRIB_RATE_800G':('ydk.models.openconfig.openconfig_transport_types', 'TRIBRATE800G'),
    'openconfig-transport-types:TRIB_RATE_900G':('ydk.models.openconfig.openconfig_transport_types', 'TRIBRATE900G'),
    'openconfig-transport-types:TRIB_SLOT_1.25G':('ydk.models.openconfig.openconfig_transport_types', 'TRIBSLOT1DOT25G'),
    'openconfig-transport-types:TRIB_SLOT_2.5G':('ydk.models.openconfig.openconfig_transport_types', 'TRIBSLOT2DOT5G'),
    'openconfig-transport-types:TRIB_SLOT_5G':('ydk.models.openconfig.openconfig_transport_types', 'TRIBSLOT5G'),
    'openconfig-transport-types:TRIBUTARY_PROTOCOL_TYPE':('ydk.models.openconfig.openconfig_transport_types', 'TRIBUTARYPROTOCOLTYPE'),
    'openconfig-transport-types:TRIBUTARY_RATE_CLASS_TYPE':('ydk.models.openconfig.openconfig_transport_types', 'TRIBUTARYRATECLASSTYPE'),
    'openconfig-transport-types:TRIBUTARY_SLOT_GRANULARITY':('ydk.models.openconfig.openconfig_transport_types', 'TRIBUTARYSLOTGRANULARITY'),
    'openconfig-transport-types:VSR2000_3R2':('ydk.models.openconfig.openconfig_transport_types', 'VSR20003R2'),
    'openconfig-transport-types:VSR2000_3R3':('ydk.models.openconfig.openconfig_transport_types', 'VSR20003R3'),
    'openconfig-transport-types:VSR2000_3R5':('ydk.models.openconfig.openconfig_transport_types', 'VSR20003R5'),
    'openconfig-transport-types:X2':('ydk.models.openconfig.openconfig_transport_types', 'X2'),
    'openconfig-transport-types:XFP':('ydk.models.openconfig.openconfig_transport_types', 'XFP'),
    'openconfig-types:ADDRESS_FAMILY':('ydk.models.openconfig.openconfig_types', 'ADDRESSFAMILY'),
    'openconfig-types:IPV4':('ydk.models.openconfig.openconfig_types', 'IPV4'),
    'openconfig-types:IPV6':('ydk.models.openconfig.openconfig_types', 'IPV6'),
    'openconfig-types:L2_ETHERNET':('ydk.models.openconfig.openconfig_types', 'L2ETHERNET'),
    'openconfig-types:MPLS':('ydk.models.openconfig.openconfig_types', 'MPLS'),
    'openconfig-vlan-types:TPID_0X9200':('ydk.models.openconfig.openconfig_vlan_types', 'TPID0X9200'),
    'openconfig-vlan-types:TPID_0x8100':('ydk.models.openconfig.openconfig_vlan_types', 'TPID0x8100'),
    'openconfig-vlan-types:TPID_0x8A88':('ydk.models.openconfig.openconfig_vlan_types', 'TPID0x8A88'),
    'openconfig-vlan-types:TPID_0x9100':('ydk.models.openconfig.openconfig_vlan_types', 'TPID0x9100'),
    'openconfig-vlan-types:TPID_TYPES':('ydk.models.openconfig.openconfig_vlan_types', 'TPIDTYPES'),
}




""" openconfig_segment_routing 

Configuration and operational state parameters relating to the
segment routing. This module defines a number of elements which are
instantiated in multiple places throughout the OpenConfig collection
of models.

Particularly\:
 \- SRGB+LB dataplane instances \- directly instantied by SR.
 \- SRGB+LB dataplane reservations \- instantiated within MPLS and future SR
                                 dataplanes.
 \- SR SID advertisements \- instantiated within the relevant IGP.
 \- SR\-specific counters \- instantied within the relevant dataplane.

"""
from collections import OrderedDict

from ydk.types import Entity as _Entity_
from ydk.types import EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YError, YModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class MplsLabel(Enum):
    """
    MplsLabel (Enum Class)

    type for MPLS label value encoding

    .. data:: IPV4_EXPLICIT_NULL = 0

        valid at the bottom of the label stack,

        indicates that stack must be popped and packet forwarded

        based on IPv4 header

    .. data:: ROUTER_ALERT = 1

        allowed anywhere in the label stack except

        the bottom, local router delivers packet to the local CPU

        when this label is at the top of the stack

    .. data:: IPV6_EXPLICIT_NULL = 2

        valid at the bottom of the label stack,

        indicates that stack must be popped and packet forwarded

        based on IPv6 header

    .. data:: IMPLICIT_NULL = 3

        assigned by local LSR but not carried in

        packets

    .. data:: ENTROPY_LABEL_INDICATOR = 7

        Entropy label indicator, to allow an LSR

        to distinguish between entropy label and applicaiton

        labels RFC 6790

    .. data:: NO_LABEL = 8

        This value is utilised to indicate that the packet that

        is forwarded by the local system does not have an MPLS

        header applied to it. Typically, this is used at the

        egress of an LSP

    """

    IPV4_EXPLICIT_NULL = Enum.YLeaf(0, "IPV4_EXPLICIT_NULL")

    ROUTER_ALERT = Enum.YLeaf(1, "ROUTER_ALERT")

    IPV6_EXPLICIT_NULL = Enum.YLeaf(2, "IPV6_EXPLICIT_NULL")

    IMPLICIT_NULL = Enum.YLeaf(3, "IMPLICIT_NULL")

    ENTROPY_LABEL_INDICATOR = Enum.YLeaf(7, "ENTROPY_LABEL_INDICATOR")

    NO_LABEL = Enum.YLeaf(8, "NO_LABEL")


class SrDataplaneType(Enum):
    """
    SrDataplaneType (Enum Class)

    Types of data plane that can be used to instantiate a Segment

    Routing block of SIDs.

    .. data:: MPLS = 0

        The entity uses MPLS labels as Segment Identifiers.

    .. data:: IPV6 = 1

        The entity uses IPv6 prefixes as Segment Identifiers.

    """

    MPLS = Enum.YLeaf(0, "MPLS")

    IPV6 = Enum.YLeaf(1, "IPV6")






""" openconfig_platform_types 

This module defines data types (e.g., YANG identities)
to support the OpenConfig component inventory model.

"""
from collections import OrderedDict

from ydk.types import Entity as _Entity_
from ydk.types import EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YError, YModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class ComponentPowerType(Enum):
    """
    ComponentPowerType (Enum Class)

    A generic type reflecting whether a hardware component

    is powered on or off

    .. data:: POWER_ENABLED = 0

        Enable power on the component

    .. data:: POWER_DISABLED = 1

        Disable power on the component

    """

    POWER_ENABLED = Enum.YLeaf(0, "POWER_ENABLED")

    POWER_DISABLED = Enum.YLeaf(1, "POWER_DISABLED")


class OPENCONFIGHARDWARECOMPONENT(Identity):
    """
    Base identity for hardware related components in a managed
    device.  Derived identities are partially based on contents
    of the IANA Entity MIB.
    
    """
    _prefix = 'oc-platform-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/platform-types", pref="openconfig-platform-types", tag="openconfig-platform-types:OPENCONFIG_HARDWARE_COMPONENT"):
        super().__init__(ns, pref, tag)


class OPENCONFIGSOFTWARECOMPONENT(Identity):
    """
    Base identity for software\-related components in a managed
    device
    
    """
    _prefix = 'oc-platform-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/platform-types", pref="openconfig-platform-types", tag="openconfig-platform-types:OPENCONFIG_SOFTWARE_COMPONENT"):
        super().__init__(ns, pref, tag)


class COMPONENTOPERSTATUS(Identity):
    """
    Current operational status of a platform component
    
    """
    _prefix = 'oc-platform-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/platform-types", pref="openconfig-platform-types", tag="openconfig-platform-types:COMPONENT_OPER_STATUS"):
        super().__init__(ns, pref, tag)


class FECMODETYPE(Identity):
    """
    Base identity for FEC operational modes.
    
    """
    _prefix = 'oc-platform-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/platform-types", pref="openconfig-platform-types", tag="openconfig-platform-types:FEC_MODE_TYPE"):
        super().__init__(ns, pref, tag)


class FECSTATUSTYPE(Identity):
    """
    Base identity for FEC operational statuses.
    
    """
    _prefix = 'oc-platform-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/platform-types", pref="openconfig-platform-types", tag="openconfig-platform-types:FEC_STATUS_TYPE"):
        super().__init__(ns, pref, tag)


class CHASSIS(OPENCONFIGHARDWARECOMPONENT):
    """
    Chassis component, typically with multiple slots / shelves
    
    """
    _prefix = 'oc-platform-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/platform-types", pref="openconfig-platform-types", tag="openconfig-platform-types:CHASSIS"):
        super().__init__(ns, pref, tag)


class BACKPLANE(OPENCONFIGHARDWARECOMPONENT):
    """
    Backplane component for aggregating traffic, typically
    contained in a chassis component
    
    """
    _prefix = 'oc-platform-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/platform-types", pref="openconfig-platform-types", tag="openconfig-platform-types:BACKPLANE"):
        super().__init__(ns, pref, tag)


class FABRIC(OPENCONFIGHARDWARECOMPONENT):
    """
    Interconnect between ingress and egress ports on the
    device (e.g., a crossbar switch).
    
    """
    _prefix = 'oc-platform-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/platform-types", pref="openconfig-platform-types", tag="openconfig-platform-types:FABRIC"):
        super().__init__(ns, pref, tag)


class POWERSUPPLY(OPENCONFIGHARDWARECOMPONENT):
    """
    Component that is supplying power to the device
    
    """
    _prefix = 'oc-platform-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/platform-types", pref="openconfig-platform-types", tag="openconfig-platform-types:POWER_SUPPLY"):
        super().__init__(ns, pref, tag)


class FAN(OPENCONFIGHARDWARECOMPONENT):
    """
    Cooling fan, or could be some other heat\-reduction component
    
    """
    _prefix = 'oc-platform-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/platform-types", pref="openconfig-platform-types", tag="openconfig-platform-types:FAN"):
        super().__init__(ns, pref, tag)


class SENSOR(OPENCONFIGHARDWARECOMPONENT):
    """
    Physical sensor, e.g., a temperature sensor in a chassis
    
    """
    _prefix = 'oc-platform-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/platform-types", pref="openconfig-platform-types", tag="openconfig-platform-types:SENSOR"):
        super().__init__(ns, pref, tag)


class FRU(OPENCONFIGHARDWARECOMPONENT):
    """
    Replaceable hardware component that does not have a more
    specific defined schema.
    
    """
    _prefix = 'oc-platform-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/platform-types", pref="openconfig-platform-types", tag="openconfig-platform-types:FRU"):
        super().__init__(ns, pref, tag)


class LINECARD(OPENCONFIGHARDWARECOMPONENT):
    """
    Linecard component, typically inserted into a chassis slot
    
    """
    _prefix = 'oc-platform-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/platform-types", pref="openconfig-platform-types", tag="openconfig-platform-types:LINECARD"):
        super().__init__(ns, pref, tag)


class CONTROLLERCARD(OPENCONFIGHARDWARECOMPONENT):
    """
    A type of linecard whose primary role is management or control
    rather than data forwarding.
    
    """
    _prefix = 'oc-platform-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/platform-types", pref="openconfig-platform-types", tag="openconfig-platform-types:CONTROLLER_CARD"):
        super().__init__(ns, pref, tag)


class PORT(OPENCONFIGHARDWARECOMPONENT):
    """
    Physical port, e.g., for attaching pluggables and networking
    cables
    
    """
    _prefix = 'oc-platform-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/platform-types", pref="openconfig-platform-types", tag="openconfig-platform-types:PORT"):
        super().__init__(ns, pref, tag)


class TRANSCEIVER(OPENCONFIGHARDWARECOMPONENT):
    """
    Pluggable module present in a port
    
    """
    _prefix = 'oc-platform-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/platform-types", pref="openconfig-platform-types", tag="openconfig-platform-types:TRANSCEIVER"):
        super().__init__(ns, pref, tag)


class CPU(OPENCONFIGHARDWARECOMPONENT):
    """
    Processing unit, e.g., a management processor
    
    """
    _prefix = 'oc-platform-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/platform-types", pref="openconfig-platform-types", tag="openconfig-platform-types:CPU"):
        super().__init__(ns, pref, tag)


class STORAGE(OPENCONFIGHARDWARECOMPONENT):
    """
    A storage subsystem on the device (disk, SSD, etc.)
    
    """
    _prefix = 'oc-platform-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/platform-types", pref="openconfig-platform-types", tag="openconfig-platform-types:STORAGE"):
        super().__init__(ns, pref, tag)


class INTEGRATEDCIRCUIT(OPENCONFIGHARDWARECOMPONENT):
    """
    A special purpose processing unit, typically for traffic
    switching/forwarding (e.g., switching ASIC, NPU, forwarding
    chip, etc.)
    
    """
    _prefix = 'oc-platform-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/platform-types", pref="openconfig-platform-types", tag="openconfig-platform-types:INTEGRATED_CIRCUIT"):
        super().__init__(ns, pref, tag)


class OPERATINGSYSTEM(OPENCONFIGSOFTWARECOMPONENT):
    """
    Operating system running on a component
    
    """
    _prefix = 'oc-platform-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/platform-types", pref="openconfig-platform-types", tag="openconfig-platform-types:OPERATING_SYSTEM"):
        super().__init__(ns, pref, tag)


class ACTIVE(COMPONENTOPERSTATUS):
    """
    Component is enabled and active (i.e., up)
    
    """
    _prefix = 'oc-platform-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/platform-types", pref="openconfig-platform-types", tag="openconfig-platform-types:ACTIVE"):
        super().__init__(ns, pref, tag)


class INACTIVE(COMPONENTOPERSTATUS):
    """
    Component is enabled but inactive (i.e., down)
    
    """
    _prefix = 'oc-platform-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/platform-types", pref="openconfig-platform-types", tag="openconfig-platform-types:INACTIVE"):
        super().__init__(ns, pref, tag)


class DISABLED(COMPONENTOPERSTATUS):
    """
    Component is administratively disabled.
    
    """
    _prefix = 'oc-platform-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/platform-types", pref="openconfig-platform-types", tag="openconfig-platform-types:DISABLED"):
        super().__init__(ns, pref, tag)


class FECENABLED(FECMODETYPE):
    """
    FEC is administratively enabled.
    
    """
    _prefix = 'oc-platform-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/platform-types", pref="openconfig-platform-types", tag="openconfig-platform-types:FEC_ENABLED"):
        super().__init__(ns, pref, tag)


class FECDISABLED(FECMODETYPE):
    """
    FEC is administratively disabled.
    
    """
    _prefix = 'oc-platform-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/platform-types", pref="openconfig-platform-types", tag="openconfig-platform-types:FEC_DISABLED"):
        super().__init__(ns, pref, tag)


class FECAUTO(FECMODETYPE):
    """
    System will determine whether to enable or disable
    FEC on a transceiver.
    
    """
    _prefix = 'oc-platform-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/platform-types", pref="openconfig-platform-types", tag="openconfig-platform-types:FEC_AUTO"):
        super().__init__(ns, pref, tag)


class FECSTATUSLOCKED(FECSTATUSTYPE):
    """
    FEC is operationally locked.
    
    """
    _prefix = 'oc-platform-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/platform-types", pref="openconfig-platform-types", tag="openconfig-platform-types:FEC_STATUS_LOCKED"):
        super().__init__(ns, pref, tag)


class FECSTATUSUNLOCKED(FECSTATUSTYPE):
    """
    FEC is operationally unlocked.
    
    """
    _prefix = 'oc-platform-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/platform-types", pref="openconfig-platform-types", tag="openconfig-platform-types:FEC_STATUS_UNLOCKED"):
        super().__init__(ns, pref, tag)






""" openconfig_packet_match_types 

This module defines common types for use in models requiring
data definitions related to packet matches.

"""
from collections import OrderedDict

from ydk.types import Entity as _Entity_
from ydk.types import EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YError, YModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class PortNumRange(Enum):
    """
    PortNumRange (Enum Class)

    Port numbers may be represented as a single value,

    an inclusive range as <lower>..<higher>, or as ANY to

    indicate a wildcard.

    .. data:: ANY = 0

        Indicates any valid port number (e.g., wildcard)

    """

    ANY = Enum.YLeaf(0, "ANY")


class ETHERTYPE(Identity):
    """
    Base identity for commonly used Ethertype values used
    in packet header matches on Ethernet frames.  The Ethertype
    indicates which protocol is encapsulated in the Ethernet
    payload.
    
    """
    _prefix = 'oc-pkt-match-types'
    _revision = '2017-05-26'

    def __init__(self, ns="http://openconfig.net/yang/packet-match-types", pref="openconfig-packet-match-types", tag="openconfig-packet-match-types:ETHERTYPE"):
        super().__init__(ns, pref, tag)


class IPPROTOCOL(Identity):
    """
    Base identity for commonly used IP protocols used in
    packet header matches
    
    """
    _prefix = 'oc-pkt-match-types'
    _revision = '2017-05-26'

    def __init__(self, ns="http://openconfig.net/yang/packet-match-types", pref="openconfig-packet-match-types", tag="openconfig-packet-match-types:IP_PROTOCOL"):
        super().__init__(ns, pref, tag)


class TCPFLAGS(Identity):
    """
    Common TCP flags used in packet header matches
    
    """
    _prefix = 'oc-pkt-match-types'
    _revision = '2017-05-26'

    def __init__(self, ns="http://openconfig.net/yang/packet-match-types", pref="openconfig-packet-match-types", tag="openconfig-packet-match-types:TCP_FLAGS"):
        super().__init__(ns, pref, tag)


class ETHERTYPEIPV4(ETHERTYPE):
    """
    IPv4 protocol (0x0800)
    
    """
    _prefix = 'oc-pkt-match-types'
    _revision = '2017-05-26'

    def __init__(self, ns="http://openconfig.net/yang/packet-match-types", pref="openconfig-packet-match-types", tag="openconfig-packet-match-types:ETHERTYPE_IPV4"):
        super().__init__(ns, pref, tag)


class ETHERTYPEARP(ETHERTYPE):
    """
    Address resolution protocol (0x0806)
    
    """
    _prefix = 'oc-pkt-match-types'
    _revision = '2017-05-26'

    def __init__(self, ns="http://openconfig.net/yang/packet-match-types", pref="openconfig-packet-match-types", tag="openconfig-packet-match-types:ETHERTYPE_ARP"):
        super().__init__(ns, pref, tag)


class ETHERTYPEVLAN(ETHERTYPE):
    """
    VLAN\-tagged frame (as defined by IEEE 802.1q) (0x8100). Note
    that this value is also used to represent Shortest Path
    Bridging (IEEE 801.1aq) frames.
    
    """
    _prefix = 'oc-pkt-match-types'
    _revision = '2017-05-26'

    def __init__(self, ns="http://openconfig.net/yang/packet-match-types", pref="openconfig-packet-match-types", tag="openconfig-packet-match-types:ETHERTYPE_VLAN"):
        super().__init__(ns, pref, tag)


class ETHERTYPEIPV6(ETHERTYPE):
    """
    IPv6 protocol (0x86DD)
    
    """
    _prefix = 'oc-pkt-match-types'
    _revision = '2017-05-26'

    def __init__(self, ns="http://openconfig.net/yang/packet-match-types", pref="openconfig-packet-match-types", tag="openconfig-packet-match-types:ETHERTYPE_IPV6"):
        super().__init__(ns, pref, tag)


class ETHERTYPEMPLS(ETHERTYPE):
    """
    MPLS unicast (0x8847)
    
    """
    _prefix = 'oc-pkt-match-types'
    _revision = '2017-05-26'

    def __init__(self, ns="http://openconfig.net/yang/packet-match-types", pref="openconfig-packet-match-types", tag="openconfig-packet-match-types:ETHERTYPE_MPLS"):
        super().__init__(ns, pref, tag)


class ETHERTYPELLDP(ETHERTYPE):
    """
    Link Layer Discovery Protocol (0x88CC)
    
    """
    _prefix = 'oc-pkt-match-types'
    _revision = '2017-05-26'

    def __init__(self, ns="http://openconfig.net/yang/packet-match-types", pref="openconfig-packet-match-types", tag="openconfig-packet-match-types:ETHERTYPE_LLDP"):
        super().__init__(ns, pref, tag)


class ETHERTYPEROCE(ETHERTYPE):
    """
    RDMA over Converged Ethernet (0x8915)
    
    """
    _prefix = 'oc-pkt-match-types'
    _revision = '2017-05-26'

    def __init__(self, ns="http://openconfig.net/yang/packet-match-types", pref="openconfig-packet-match-types", tag="openconfig-packet-match-types:ETHERTYPE_ROCE"):
        super().__init__(ns, pref, tag)


class IPTCP(IPPROTOCOL):
    """
    Transmission Control Protocol (6)
    
    """
    _prefix = 'oc-pkt-match-types'
    _revision = '2017-05-26'

    def __init__(self, ns="http://openconfig.net/yang/packet-match-types", pref="openconfig-packet-match-types", tag="openconfig-packet-match-types:IP_TCP"):
        super().__init__(ns, pref, tag)


class IPUDP(IPPROTOCOL):
    """
    User Datagram Protocol (17)
    
    """
    _prefix = 'oc-pkt-match-types'
    _revision = '2017-05-26'

    def __init__(self, ns="http://openconfig.net/yang/packet-match-types", pref="openconfig-packet-match-types", tag="openconfig-packet-match-types:IP_UDP"):
        super().__init__(ns, pref, tag)


class IPICMP(IPPROTOCOL):
    """
    Internet Control Message Protocol (1)
    
    """
    _prefix = 'oc-pkt-match-types'
    _revision = '2017-05-26'

    def __init__(self, ns="http://openconfig.net/yang/packet-match-types", pref="openconfig-packet-match-types", tag="openconfig-packet-match-types:IP_ICMP"):
        super().__init__(ns, pref, tag)


class IPIGMP(IPPROTOCOL):
    """
    Internet Group Membership Protocol (2)
    
    """
    _prefix = 'oc-pkt-match-types'
    _revision = '2017-05-26'

    def __init__(self, ns="http://openconfig.net/yang/packet-match-types", pref="openconfig-packet-match-types", tag="openconfig-packet-match-types:IP_IGMP"):
        super().__init__(ns, pref, tag)


class IPPIM(IPPROTOCOL):
    """
    Protocol Independent Multicast (103)
    
    """
    _prefix = 'oc-pkt-match-types'
    _revision = '2017-05-26'

    def __init__(self, ns="http://openconfig.net/yang/packet-match-types", pref="openconfig-packet-match-types", tag="openconfig-packet-match-types:IP_PIM"):
        super().__init__(ns, pref, tag)


class IPRSVP(IPPROTOCOL):
    """
    Resource Reservation Protocol (46)
    
    """
    _prefix = 'oc-pkt-match-types'
    _revision = '2017-05-26'

    def __init__(self, ns="http://openconfig.net/yang/packet-match-types", pref="openconfig-packet-match-types", tag="openconfig-packet-match-types:IP_RSVP"):
        super().__init__(ns, pref, tag)


class IPGRE(IPPROTOCOL):
    """
    Generic Routing Encapsulation (47)
    
    """
    _prefix = 'oc-pkt-match-types'
    _revision = '2017-05-26'

    def __init__(self, ns="http://openconfig.net/yang/packet-match-types", pref="openconfig-packet-match-types", tag="openconfig-packet-match-types:IP_GRE"):
        super().__init__(ns, pref, tag)


class IPAUTH(IPPROTOCOL):
    """
    Authentication header, e.g., for IPSEC (51)
    
    """
    _prefix = 'oc-pkt-match-types'
    _revision = '2017-05-26'

    def __init__(self, ns="http://openconfig.net/yang/packet-match-types", pref="openconfig-packet-match-types", tag="openconfig-packet-match-types:IP_AUTH"):
        super().__init__(ns, pref, tag)


class IPL2TP(IPPROTOCOL):
    """
    Layer Two Tunneling Protocol v.3 (115)
    
    """
    _prefix = 'oc-pkt-match-types'
    _revision = '2017-05-26'

    def __init__(self, ns="http://openconfig.net/yang/packet-match-types", pref="openconfig-packet-match-types", tag="openconfig-packet-match-types:IP_L2TP"):
        super().__init__(ns, pref, tag)


class TCPSYN(TCPFLAGS):
    """
    TCP SYN flag
    
    """
    _prefix = 'oc-pkt-match-types'
    _revision = '2017-05-26'

    def __init__(self, ns="http://openconfig.net/yang/packet-match-types", pref="openconfig-packet-match-types", tag="openconfig-packet-match-types:TCP_SYN"):
        super().__init__(ns, pref, tag)


class TCPFIN(TCPFLAGS):
    """
    TCP FIN flag
    
    """
    _prefix = 'oc-pkt-match-types'
    _revision = '2017-05-26'

    def __init__(self, ns="http://openconfig.net/yang/packet-match-types", pref="openconfig-packet-match-types", tag="openconfig-packet-match-types:TCP_FIN"):
        super().__init__(ns, pref, tag)


class TCPRST(TCPFLAGS):
    """
    TCP RST flag
    
    """
    _prefix = 'oc-pkt-match-types'
    _revision = '2017-05-26'

    def __init__(self, ns="http://openconfig.net/yang/packet-match-types", pref="openconfig-packet-match-types", tag="openconfig-packet-match-types:TCP_RST"):
        super().__init__(ns, pref, tag)


class TCPPSH(TCPFLAGS):
    """
    TCP push flag
    
    """
    _prefix = 'oc-pkt-match-types'
    _revision = '2017-05-26'

    def __init__(self, ns="http://openconfig.net/yang/packet-match-types", pref="openconfig-packet-match-types", tag="openconfig-packet-match-types:TCP_PSH"):
        super().__init__(ns, pref, tag)


class TCPACK(TCPFLAGS):
    """
    TCP ACK flag
    
    """
    _prefix = 'oc-pkt-match-types'
    _revision = '2017-05-26'

    def __init__(self, ns="http://openconfig.net/yang/packet-match-types", pref="openconfig-packet-match-types", tag="openconfig-packet-match-types:TCP_ACK"):
        super().__init__(ns, pref, tag)


class TCPURG(TCPFLAGS):
    """
    TCP urgent flag
    
    """
    _prefix = 'oc-pkt-match-types'
    _revision = '2017-05-26'

    def __init__(self, ns="http://openconfig.net/yang/packet-match-types", pref="openconfig-packet-match-types", tag="openconfig-packet-match-types:TCP_URG"):
        super().__init__(ns, pref, tag)


class TCPECE(TCPFLAGS):
    """
    TCP ECN\-Echo flag.  If the SYN flag is set, indicates that
    the TCP peer is ECN\-capable, otherwise indicates that a
    packet with Congestion Experienced flag in the IP header
    is set
    
    """
    _prefix = 'oc-pkt-match-types'
    _revision = '2017-05-26'

    def __init__(self, ns="http://openconfig.net/yang/packet-match-types", pref="openconfig-packet-match-types", tag="openconfig-packet-match-types:TCP_ECE"):
        super().__init__(ns, pref, tag)


class TCPCWR(TCPFLAGS):
    """
    TCP Congestion Window Reduced flag
    
    """
    _prefix = 'oc-pkt-match-types'
    _revision = '2017-05-26'

    def __init__(self, ns="http://openconfig.net/yang/packet-match-types", pref="openconfig-packet-match-types", tag="openconfig-packet-match-types:TCP_CWR"):
        super().__init__(ns, pref, tag)



